{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "import numpy as np\n",
    "import matplotlib.pyplot as plt\n",
    "%matplotlib inline\n",
    "import matplotlib_inline\n",
    "matplotlib_inline.backend_inline.set_matplotlib_formats('svg')\n",
    "import seaborn as sns\n",
    "sns.set_context(\"paper\")\n",
    "sns.set_style(\"ticks\")\n",
    "\n",
    "import torch\n",
    "import gpytorch\n",
    "from gpytorch.kernels import RBFKernel, ScaleKernel\n",
    "\n",
    "class ExactGP(gpytorch.models.ExactGP):\n",
    "    def __init__(self,\n",
    "                 train_x,\n",
    "                 train_y,\n",
    "                 likelihood=gpytorch.likelihoods.GaussianLikelihood(\n",
    "                     noise_constraint=gpytorch.constraints.GreaterThan(0.0)\n",
    "                ),\n",
    "                mean_module=gpytorch.means.ConstantMean(),\n",
    "                covar_module=ScaleKernel(RBFKernel())\n",
    "        ):\n",
    "        super().__init__(train_x, train_y, likelihood)\n",
    "        self.mean_module = mean_module\n",
    "        self.covar_module = covar_module\n",
    "\n",
    "    def forward(self, x):\n",
    "        mean_x = self.mean_module(x)\n",
    "        covar_x = self.covar_module(x)\n",
    "        return gpytorch.distributions.MultivariateNormal(mean_x, covar_x)\n",
    "\n",
    "\n",
    "def plot_1d_regression(\n",
    "    x_star,\n",
    "    model,\n",
    "    ax=None,\n",
    "    f_true=None,\n",
    "    num_samples=10\n",
    "):\n",
    "    \"\"\"Plot the posterior predictive.\n",
    "    \n",
    "    Arguments\n",
    "    x_start  --  The test points on which to evaluate.\n",
    "    model    --  The trained model.\n",
    "    \n",
    "    Keyword Arguments\n",
    "    ax          --  An axes object to write on.\n",
    "    f_true      --  The true function.\n",
    "    num_samples --  The number of samples.\n",
    "    \"\"\"\n",
    "    f_star = model(x_star)\n",
    "    m_star = f_star.mean\n",
    "    v_star = f_star.variance\n",
    "    y_star = model.likelihood(f_star)\n",
    "    yv_star = y_star.variance\n",
    "\n",
    "    f_lower = (\n",
    "        m_star - 2.0 * torch.sqrt(v_star)\n",
    "    )\n",
    "    f_upper = (\n",
    "        m_star + 2.0 * torch.sqrt(v_star)\n",
    "    )\n",
    "    \n",
    "    y_lower = m_star - 2.0 * torch.sqrt(yv_star)\n",
    "    y_upper = m_star + 2.0 * torch.sqrt(yv_star)\n",
    "\n",
    "    if ax is None:\n",
    "        fig, ax = plt.subplots()\n",
    "    \n",
    "    ax.plot(model.train_inputs[0].flatten().detach(),\n",
    "            model.train_targets.detach(),\n",
    "            'kx',\n",
    "            markersize=10,\n",
    "            markeredgewidth=2,\n",
    "            label='Observations'\n",
    "    )\n",
    "\n",
    "    ax.plot(\n",
    "        x_star,\n",
    "        m_star.detach(),\n",
    "        lw=2,\n",
    "        label='$m_n(x)$',\n",
    "        color=sns.color_palette()[0]\n",
    "    )\n",
    "    \n",
    "    ax.fill_between(\n",
    "        x_star.flatten().detach(),\n",
    "        f_lower.flatten().detach(),\n",
    "        f_upper.flatten().detach(),\n",
    "        alpha=0.5,\n",
    "        label='$f(\\mathbf{x}^*)$ 95% pred.',\n",
    "        color=sns.color_palette()[0]\n",
    "    )\n",
    "\n",
    "    ax.fill_between(\n",
    "        x_star.detach().flatten(),\n",
    "        y_lower.detach().flatten(),\n",
    "        f_lower.detach().flatten(),\n",
    "        color=sns.color_palette()[1],\n",
    "        alpha=0.5,\n",
    "        label='$y^*$ 95% pred.'\n",
    "    )\n",
    "    ax.fill_between(\n",
    "        x_star.detach().flatten(),\n",
    "        f_upper.detach().flatten(),\n",
    "        y_upper.detach().flatten(),\n",
    "        color=sns.color_palette()[1],\n",
    "        alpha=0.5,\n",
    "        label=None\n",
    "    )\n",
    "\n",
    "    \n",
    "    if f_true is not None:\n",
    "        ax.plot(\n",
    "            x_star,\n",
    "            f_true(x_star),\n",
    "            'm-.',\n",
    "            label='True function'\n",
    "        )\n",
    "        \n",
    "    if num_samples > 0:\n",
    "        f_post_samples = f_star.sample(\n",
    "            sample_shape=torch.Size([10])\n",
    "        )\n",
    "        ax.plot(\n",
    "            x_star.numpy(),\n",
    "            f_post_samples.T.detach().numpy(),\n",
    "            color=\"red\",\n",
    "            lw=0.5\n",
    "        )\n",
    "        # This is just to add the legend entry\n",
    "        ax.plot(\n",
    "            [],\n",
    "            [],\n",
    "            color=\"red\",\n",
    "            lw=0.5,\n",
    "            label=\"Posterior samples\"\n",
    "        )\n",
    "        \n",
    "    ax.set_xlabel('$x$')\n",
    "    ax.set_ylabel('$y$')\n",
    "\n",
    "    plt.legend(loc='best', frameon=False)\n",
    "    sns.despine(trim=True);\n",
    "\n",
    "def train(model, train_x, train_y, n_iter=10, lr=0.1):\n",
    "    \"\"\"Train the model.\n",
    "\n",
    "    Arguments\n",
    "    model   --  The model to train.\n",
    "    train_x --  The training inputs.\n",
    "    train_y --  The training labels.\n",
    "    n_iter  --  The number of iterations.\n",
    "    \"\"\"\n",
    "    model.train()\n",
    "    optimizer = torch.optim.LBFGS(model.parameters(), line_search_fn='strong_wolfe')\n",
    "    likelihood = model.likelihood\n",
    "    mll = gpytorch.mlls.ExactMarginalLogLikelihood(likelihood, model)\n",
    "    def closure():\n",
    "        optimizer.zero_grad()\n",
    "        output = model(train_x)\n",
    "        loss = -mll(output, train_y)\n",
    "        loss.backward()\n",
    "        return loss\n",
    "    for i in range(n_iter):\n",
    "        loss = optimizer.step(closure)\n",
    "        if (i + 1) % 1 == 0:\n",
    "            print(f'Iter {i + 1:3d}/{n_iter} - Loss: {loss.item():.3f}')\n",
    "    model.eval()\n",
    "\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "!pip install gpytorch"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Maximum Mean - A Bad Information Acquisition Function\n",
    "\n",
    "An naive information acquisition function is to select the arm with the highest mean. This is a bad idea. You should never do this. We will show why."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Working 1D Example\n",
    "\n",
    "It is easier to introduce the ideas using an example.\n",
    "Let's work with a synthetic 1D function defined in $[0,1]$:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"402.632875pt\" height=\"309.639375pt\" viewBox=\"0 0 402.632875 309.639375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:17:14.235655</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 309.639375 \n",
       "L 402.632875 309.639375 \n",
       "L 402.632875 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 273.312 \n",
       "L 395.432875 273.312 \n",
       "L 395.432875 7.2 \n",
       "L 38.312875 7.2 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m0bb2084f9c\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0bb2084f9c\" x=\"54.545602\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0bb2084f9c\" x=\"119.476511\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0bb2084f9c\" x=\"184.40742\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0bb2084f9c\" x=\"249.33833\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0bb2084f9c\" x=\"314.269239\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m0bb2084f9c\" x=\"379.200148\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 300.531375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"m068e79171b\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m068e79171b\" x=\"38.312875\" y=\"261.605642\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 264.755079) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m068e79171b\" x=\"38.312875\" y=\"231.292426\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −7 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 234.441863) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-37\" d=\"M 303 3981 \n",
       "L 303 4522 \n",
       "L 3269 4522 \n",
       "L 3269 4084 \n",
       "Q 2831 3619 2401 2847 \n",
       "Q 1972 2075 1738 1259 \n",
       "Q 1569 684 1522 0 \n",
       "L 944 0 \n",
       "Q 953 541 1156 1306 \n",
       "Q 1359 2072 1739 2783 \n",
       "Q 2119 3494 2547 3981 \n",
       "L 303 3981 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m068e79171b\" x=\"38.312875\" y=\"200.979209\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 204.128647) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m068e79171b\" x=\"38.312875\" y=\"170.665993\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 173.81543) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m068e79171b\" x=\"38.312875\" y=\"140.352776\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 143.502214) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m068e79171b\" x=\"38.312875\" y=\"110.03956\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −3 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 113.188998) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m068e79171b\" x=\"38.312875\" y=\"79.726344\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 82.875781) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m068e79171b\" x=\"38.312875\" y=\"49.413127\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 52.562565) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m068e79171b\" x=\"38.312875\" y=\"19.099911\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 22.249348) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 143.136) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <path d=\"M 54.545602 139.468238 \n",
       "L 61.171205 124.550794 \n",
       "L 67.796808 109.85914 \n",
       "L 74.422411 95.616397 \n",
       "L 81.048014 82.040103 \n",
       "L 87.673617 69.339131 \n",
       "L 94.29922 57.710736 \n",
       "L 100.924823 47.337784 \n",
       "L 107.550426 38.386177 \n",
       "L 114.176029 31.002521 \n",
       "L 120.801632 25.312053 \n",
       "L 127.427235 21.41685 \n",
       "L 134.052838 19.394321 \n",
       "L 140.678441 19.296 \n",
       "L 147.304044 21.146622 \n",
       "L 153.929647 24.943477 \n",
       "L 160.55525 30.656022 \n",
       "L 167.180853 38.225713 \n",
       "L 173.806456 47.566037 \n",
       "L 180.432059 58.562677 \n",
       "L 187.057662 71.073777 \n",
       "L 193.683265 84.930247 \n",
       "L 200.308868 99.936038 \n",
       "L 206.934471 115.868338 \n",
       "L 213.560074 132.477632 \n",
       "L 220.185676 149.487572 \n",
       "L 226.811279 166.594647 \n",
       "L 233.436882 183.467657 \n",
       "L 240.062485 199.747051 \n",
       "L 246.688088 215.044288 \n",
       "L 253.313691 228.941484 \n",
       "L 259.939294 240.9918 \n",
       "L 266.564897 250.721265 \n",
       "L 273.1905 257.633089 \n",
       "L 279.816103 261.216 \n",
       "L 286.441706 260.958737 \n",
       "L 293.067309 256.373654 \n",
       "L 299.692912 247.033265 \n",
       "L 306.318515 232.624515 \n",
       "L 312.944118 213.026234 \n",
       "L 319.569721 188.415149 \n",
       "L 326.195324 159.403855 \n",
       "L 332.820927 127.208631 \n",
       "L 339.44653 93.83311 \n",
       "L 346.072133 62.231661 \n",
       "L 352.697736 36.379852 \n",
       "L 359.323339 21.126169 \n",
       "L 365.948942 21.635933 \n",
       "L 372.574545 42.193372 \n",
       "L 379.200148 84.173414 \n",
       "\" clip-path=\"url(#p938a6e8341)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 261.605642 \n",
       "L 38.312875 19.099911 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 273.312 \n",
       "L 379.200148 273.312 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p938a6e8341\">\n",
       "   <rect x=\"38.312875\" y=\"7.2\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "def f(x):\n",
    "    \"\"\"A function to optimize.\"\"\"\n",
    "    return -4 * (1. - np.sin(6 * x + 8 * np.exp(6 * x - 7.))) \n",
    "\n",
    "x = np.linspace(0, 1)\n",
    "plt.plot(x, f(x), linewidth=2)\n",
    "plt.xlabel('$x$')\n",
    "plt.ylabel('$y$')\n",
    "sns.despine(trim=True);"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "We wish to maximize this function.\n",
    "Let us generate some starting data:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"414.864875pt\" height=\"309.639375pt\" viewBox=\"0 0 414.864875 309.639375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:17:14.325378</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 309.639375 \n",
       "L 414.864875 309.639375 \n",
       "L 414.864875 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 50.544875 273.312 \n",
       "L 407.664875 273.312 \n",
       "L 407.664875 7.2 \n",
       "L 50.544875 7.2 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m4fdf202273\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m4fdf202273\" x=\"73.778876\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(67.662876 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m4fdf202273\" x=\"117.315919\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.3 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(111.199919 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m4fdf202273\" x=\"160.852962\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(154.736962 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m4fdf202273\" x=\"204.390005\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(198.274005 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m4fdf202273\" x=\"247.927048\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(241.811048 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m4fdf202273\" x=\"291.464091\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 0.7 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(285.348091 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-37\" d=\"M 303 3981 \n",
       "L 303 4522 \n",
       "L 3269 4522 \n",
       "L 3269 4084 \n",
       "Q 2831 3619 2401 2847 \n",
       "Q 1972 2075 1738 1259 \n",
       "Q 1569 684 1522 0 \n",
       "L 944 0 \n",
       "Q 953 541 1156 1306 \n",
       "Q 1359 2072 1739 2783 \n",
       "Q 2119 3494 2547 3981 \n",
       "L 303 3981 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m4fdf202273\" x=\"335.001134\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(328.885134 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m4fdf202273\" x=\"378.538177\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- 0.9 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(372.422177 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-39\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_9\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(226.224875 300.531375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <defs>\n",
       "       <path id=\"m557a71790c\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m557a71790c\" x=\"50.544875\" y=\"245.1672\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −0.38 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 248.316637) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m557a71790c\" x=\"50.544875\" y=\"213.255195\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −0.36 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 216.404633) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m557a71790c\" x=\"50.544875\" y=\"181.343191\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −0.34 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 184.492628) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m557a71790c\" x=\"50.544875\" y=\"149.431186\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −0.32 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 152.580624) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m557a71790c\" x=\"50.544875\" y=\"117.519182\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- −0.30 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 120.668619) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m557a71790c\" x=\"50.544875\" y=\"85.607177\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- −0.28 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 88.756615) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m557a71790c\" x=\"50.544875\" y=\"53.695173\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- −0.26 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 56.84461) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_16\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m557a71790c\" x=\"50.544875\" y=\"21.783168\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_17\">\n",
       "      <!-- −0.24 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 24.932606) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 143.136) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_17\">\n",
       "    <defs>\n",
       "     <path id=\"mc334918dbe\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p1e4e43dbd0)\">\n",
       "     <use xlink:href=\"#mc334918dbe\" x=\"391.432148\" y=\"19.296\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mc334918dbe\" x=\"124.445351\" y=\"85.049893\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mc334918dbe\" x=\"66.777602\" y=\"261.216\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 50.544875 245.1672 \n",
       "L 50.544875 21.783168 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 73.778876 273.312 \n",
       "L 378.538177 273.312 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p1e4e43dbd0\">\n",
       "   <rect x=\"50.544875\" y=\"7.2\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "np.random.seed(12345)\n",
    "\n",
    "n_init = 3\n",
    "\n",
    "X = np.random.rand(n_init)\n",
    "Y = f(X)\n",
    "\n",
    "plt.plot(X, Y, 'kx', markersize=10, markeredgewidth=2)\n",
    "plt.xlabel('$x$')\n",
    "plt.ylabel('$y$')\n",
    "sns.despine(trim=True);"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Assume we do some Bayesian regression using our data so far.\n",
    "Here, we will do GPR, but any Bayesian regression would work.\n",
    "We will not work right now with the full predictive $p(f(\\cdot)|\\mathcal{D}_{n})$, but with the point-predictive distribution:\n",
    "$$\n",
    "p(y|\\mathbf{x},\\mathcal{D}_{n}) = \\mathcal{N}\\left(y|m_{n}(\\mathbf{x}), \\sigma^2_{n}(\\mathbf{x})\\right),\n",
    "$$\n",
    "where $m_{n}(\\mathbf{x})$ and $\\sigma^2_{n}(\\mathbf{x})$ are the predictive mean and variance respectively.\n",
    "\n",
    "Here is an example with GPR:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/Users/ibilion/.pyenv/versions/3.11.6/lib/python3.11/site-packages/linear_operator/utils/cholesky.py:40: NumericalWarning: A not p.d., added jitter of 1.0e-06 to the diagonal\n",
      "  warnings.warn(\n",
      "/Users/ibilion/.pyenv/versions/3.11.6/lib/python3.11/site-packages/linear_operator/utils/cholesky.py:40: NumericalWarning: A not p.d., added jitter of 1.0e-05 to the diagonal\n",
      "  warnings.warn(\n"
     ]
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"402.632875pt\" height=\"309.639375pt\" viewBox=\"0 0 402.632875 309.639375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:17:14.441302</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 309.639375 \n",
       "L 402.632875 309.639375 \n",
       "L 402.632875 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 273.312 \n",
       "L 395.432875 273.312 \n",
       "L 395.432875 7.2 \n",
       "L 38.312875 7.2 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"mb95628e7b1\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb95628e7b1\" x=\"54.545602\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb95628e7b1\" x=\"119.476511\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb95628e7b1\" x=\"184.40742\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb95628e7b1\" x=\"249.33833\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb95628e7b1\" x=\"314.269239\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb95628e7b1\" x=\"379.200148\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 300.531375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"m19346f45bc\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m19346f45bc\" x=\"38.312875\" y=\"261.478006\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 264.627444) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m19346f45bc\" x=\"38.312875\" y=\"220.710317\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 223.859755) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m19346f45bc\" x=\"38.312875\" y=\"179.942629\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 183.092066) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m19346f45bc\" x=\"38.312875\" y=\"139.17494\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 142.324377) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m19346f45bc\" x=\"38.312875\" y=\"98.407251\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 101.556689) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m19346f45bc\" x=\"38.312875\" y=\"57.639562\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 60.789) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m19346f45bc\" x=\"38.312875\" y=\"16.871874\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 20.021311) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-34\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_15\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 143.136) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m4210af5aed\" d=\"M 54.545602 -275.593214 \n",
       "L 54.545602 -139.618556 \n",
       "L 61.171205 -143.995443 \n",
       "L 67.796808 -149.42542 \n",
       "L 74.422411 -155.884088 \n",
       "L 81.048014 -163.253704 \n",
       "L 87.673618 -171.316303 \n",
       "L 94.29922 -179.757801 \n",
       "L 100.924825 -188.183856 \n",
       "L 107.550425 -196.145024 \n",
       "L 114.17603 -202.861605 \n",
       "L 120.801634 -197.703197 \n",
       "L 127.427234 -194.067743 \n",
       "L 134.052839 -192.673568 \n",
       "L 140.678438 -193.62218 \n",
       "L 147.304048 -196.855282 \n",
       "L 153.929648 -202.154016 \n",
       "L 160.555248 -202.418149 \n",
       "L 167.180857 -195.331229 \n",
       "L 173.806457 -187.398017 \n",
       "L 180.432057 -179.084888 \n",
       "L 187.057666 -170.822968 \n",
       "L 193.683266 -162.983027 \n",
       "L 200.308866 -155.852222 \n",
       "L 206.934475 -149.621647 \n",
       "L 213.560075 -144.385765 \n",
       "L 220.185675 -140.15224 \n",
       "L 226.811275 -136.859826 \n",
       "L 233.436875 -134.401166 \n",
       "L 240.062494 -132.647125 \n",
       "L 246.688093 -131.469925 \n",
       "L 253.313693 -130.76267 \n",
       "L 259.939293 -130.45398 \n",
       "L 266.564893 -130.51692 \n",
       "L 273.190493 -130.972277 \n",
       "L 279.816112 -131.88633 \n",
       "L 286.441712 -133.363677 \n",
       "L 293.067312 -135.535561 \n",
       "L 299.692911 -138.544657 \n",
       "L 306.318511 -142.527349 \n",
       "L 312.944111 -147.595099 \n",
       "L 319.56973 -153.816814 \n",
       "L 326.19533 -161.204134 \n",
       "L 332.82093 -169.701574 \n",
       "L 339.44653 -179.183245 \n",
       "L 346.072129 -189.456199 \n",
       "L 352.697729 -200.266529 \n",
       "L 359.323348 -201.390033 \n",
       "L 365.948948 -190.543064 \n",
       "L 372.574548 -180.202973 \n",
       "L 379.200148 -170.630587 \n",
       "L 379.200148 -243.126769 \n",
       "L 379.200148 -243.126769 \n",
       "L 372.574548 -233.065867 \n",
       "L 365.948948 -222.387945 \n",
       "L 359.323348 -211.371943 \n",
       "L 352.697729 -212.504426 \n",
       "L 346.072129 -223.501192 \n",
       "L 339.44653 -234.127726 \n",
       "L 332.82093 -244.110981 \n",
       "L 326.19533 -253.231706 \n",
       "L 319.56973 -261.332721 \n",
       "L 312.944111 -268.324747 \n",
       "L 306.318511 -274.185582 \n",
       "L 299.692911 -278.952426 \n",
       "L 293.067312 -282.708808 \n",
       "L 286.441712 -285.568055 \n",
       "L 279.816112 -287.654997 \n",
       "L 273.190493 -289.088115 \n",
       "L 266.564893 -289.963531 \n",
       "L 259.939293 -290.342335 \n",
       "L 253.313693 -290.242182 \n",
       "L 246.688093 -289.633895 \n",
       "L 240.062494 -288.443747 \n",
       "L 233.436875 -286.561766 \n",
       "L 226.811275 -283.856077 \n",
       "L 220.185675 -280.192718 \n",
       "L 213.560075 -275.45947 \n",
       "L 206.934475 -269.591316 \n",
       "L 200.308866 -262.594697 \n",
       "L 193.683266 -254.567087 \n",
       "L 187.057666 -245.708421 \n",
       "L 180.432057 -236.321904 \n",
       "L 173.806457 -226.802543 \n",
       "L 167.180857 -217.614068 \n",
       "L 160.555248 -209.263255 \n",
       "L 153.929648 -208.301508 \n",
       "L 147.304048 -212.462826 \n",
       "L 140.678438 -214.698058 \n",
       "L 134.052839 -214.836416 \n",
       "L 127.427234 -212.860891 \n",
       "L 120.801634 -208.904076 \n",
       "L 114.17603 -203.702417 \n",
       "L 107.550425 -210.657364 \n",
       "L 100.924825 -219.127015 \n",
       "L 94.29922 -228.306072 \n",
       "L 87.673618 -237.707562 \n",
       "L 81.048014 -246.890837 \n",
       "L 74.422411 -255.49047 \n",
       "L 67.796808 -263.236018 \n",
       "L 61.171205 -269.959812 \n",
       "L 54.545602 -275.593214 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p10999bb007)\">\n",
       "     <use xlink:href=\"#m4210af5aed\" x=\"0\" y=\"309.639375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m47207115aa\" d=\"M 54.545602 -139.618556 \n",
       "L 54.545602 -139.617331 \n",
       "L 61.171205 -143.994121 \n",
       "L 67.796808 -149.423957 \n",
       "L 74.422411 -155.882421 \n",
       "L 81.048014 -163.251721 \n",
       "L 87.673618 -171.3138 \n",
       "L 94.29922 -179.754377 \n",
       "L 100.924825 -188.178486 \n",
       "L 107.550425 -196.133582 \n",
       "L 114.17603 -202.696398 \n",
       "L 120.801634 -197.688377 \n",
       "L 127.427234 -194.058903 \n",
       "L 134.052839 -192.666072 \n",
       "L 140.678438 -193.614298 \n",
       "L 147.304048 -196.844642 \n",
       "L 153.929648 -202.127098 \n",
       "L 160.555248 -202.393954 \n",
       "L 167.180857 -195.323774 \n",
       "L 173.806457 -187.393801 \n",
       "L 180.432057 -179.081987 \n",
       "L 187.057666 -170.820747 \n",
       "L 193.683266 -162.98121 \n",
       "L 200.308866 -155.850662 \n",
       "L 206.934475 -149.620262 \n",
       "L 213.560075 -144.384497 \n",
       "L 220.185675 -140.151054 \n",
       "L 226.811275 -136.858699 \n",
       "L 233.436875 -134.400077 \n",
       "L 240.062494 -132.646056 \n",
       "L 246.688093 -131.468875 \n",
       "L 253.313693 -130.76163 \n",
       "L 259.939293 -130.45294 \n",
       "L 266.564893 -130.51588 \n",
       "L 273.190493 -130.971227 \n",
       "L 279.816112 -131.885265 \n",
       "L 286.441712 -133.362588 \n",
       "L 293.067312 -135.534433 \n",
       "L 299.692911 -138.543476 \n",
       "L 306.318511 -142.52609 \n",
       "L 312.944111 -147.593723 \n",
       "L 319.56973 -153.815268 \n",
       "L 326.19533 -161.202326 \n",
       "L 332.82093 -169.699338 \n",
       "L 339.44653 -179.18022 \n",
       "L 346.072129 -189.451319 \n",
       "L 352.697729 -200.252964 \n",
       "L 359.323348 -201.37341 \n",
       "L 365.948948 -190.537847 \n",
       "L 372.574548 -180.199832 \n",
       "L 379.200148 -170.628293 \n",
       "L 379.200148 -170.630587 \n",
       "L 379.200148 -170.630587 \n",
       "L 372.574548 -180.202973 \n",
       "L 365.948948 -190.543064 \n",
       "L 359.323348 -201.390033 \n",
       "L 352.697729 -200.266529 \n",
       "L 346.072129 -189.456199 \n",
       "L 339.44653 -179.183245 \n",
       "L 332.82093 -169.701574 \n",
       "L 326.19533 -161.204134 \n",
       "L 319.56973 -153.816814 \n",
       "L 312.944111 -147.595099 \n",
       "L 306.318511 -142.527349 \n",
       "L 299.692911 -138.544657 \n",
       "L 293.067312 -135.535561 \n",
       "L 286.441712 -133.363677 \n",
       "L 279.816112 -131.88633 \n",
       "L 273.190493 -130.972277 \n",
       "L 266.564893 -130.51692 \n",
       "L 259.939293 -130.45398 \n",
       "L 253.313693 -130.76267 \n",
       "L 246.688093 -131.469925 \n",
       "L 240.062494 -132.647125 \n",
       "L 233.436875 -134.401166 \n",
       "L 226.811275 -136.859826 \n",
       "L 220.185675 -140.15224 \n",
       "L 213.560075 -144.385765 \n",
       "L 206.934475 -149.621647 \n",
       "L 200.308866 -155.852222 \n",
       "L 193.683266 -162.983027 \n",
       "L 187.057666 -170.822968 \n",
       "L 180.432057 -179.084888 \n",
       "L 173.806457 -187.398017 \n",
       "L 167.180857 -195.331229 \n",
       "L 160.555248 -202.418149 \n",
       "L 153.929648 -202.154016 \n",
       "L 147.304048 -196.855282 \n",
       "L 140.678438 -193.62218 \n",
       "L 134.052839 -192.673568 \n",
       "L 127.427234 -194.067743 \n",
       "L 120.801634 -197.703197 \n",
       "L 114.17603 -202.861605 \n",
       "L 107.550425 -196.145024 \n",
       "L 100.924825 -188.183856 \n",
       "L 94.29922 -179.757801 \n",
       "L 87.673618 -171.316303 \n",
       "L 81.048014 -163.253704 \n",
       "L 74.422411 -155.884088 \n",
       "L 67.796808 -149.42542 \n",
       "L 61.171205 -143.995443 \n",
       "L 54.545602 -139.618556 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p10999bb007)\">\n",
       "     <use xlink:href=\"#m47207115aa\" x=\"0\" y=\"309.639375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m983946f399\" d=\"M 54.545602 -275.594439 \n",
       "L 54.545602 -275.593214 \n",
       "L 61.171205 -269.959812 \n",
       "L 67.796808 -263.236018 \n",
       "L 74.422411 -255.49047 \n",
       "L 81.048014 -246.890837 \n",
       "L 87.673618 -237.707562 \n",
       "L 94.29922 -228.306072 \n",
       "L 100.924825 -219.127015 \n",
       "L 107.550425 -210.657364 \n",
       "L 114.17603 -203.702417 \n",
       "L 120.801634 -208.904076 \n",
       "L 127.427234 -212.860891 \n",
       "L 134.052839 -214.836416 \n",
       "L 140.678438 -214.698058 \n",
       "L 147.304048 -212.462826 \n",
       "L 153.929648 -208.301508 \n",
       "L 160.555248 -209.263255 \n",
       "L 167.180857 -217.614068 \n",
       "L 173.806457 -226.802543 \n",
       "L 180.432057 -236.321904 \n",
       "L 187.057666 -245.708421 \n",
       "L 193.683266 -254.567087 \n",
       "L 200.308866 -262.594697 \n",
       "L 206.934475 -269.591316 \n",
       "L 213.560075 -275.45947 \n",
       "L 220.185675 -280.192718 \n",
       "L 226.811275 -283.856077 \n",
       "L 233.436875 -286.561766 \n",
       "L 240.062494 -288.443747 \n",
       "L 246.688093 -289.633895 \n",
       "L 253.313693 -290.242182 \n",
       "L 259.939293 -290.342335 \n",
       "L 266.564893 -289.963531 \n",
       "L 273.190493 -289.088115 \n",
       "L 279.816112 -287.654997 \n",
       "L 286.441712 -285.568055 \n",
       "L 293.067312 -282.708808 \n",
       "L 299.692911 -278.952426 \n",
       "L 306.318511 -274.185582 \n",
       "L 312.944111 -268.324747 \n",
       "L 319.56973 -261.332721 \n",
       "L 326.19533 -253.231706 \n",
       "L 332.82093 -244.110981 \n",
       "L 339.44653 -234.127726 \n",
       "L 346.072129 -223.501192 \n",
       "L 352.697729 -212.504426 \n",
       "L 359.323348 -211.371943 \n",
       "L 365.948948 -222.387945 \n",
       "L 372.574548 -233.065867 \n",
       "L 379.200148 -243.126769 \n",
       "L 379.200148 -243.129063 \n",
       "L 379.200148 -243.129063 \n",
       "L 372.574548 -233.069009 \n",
       "L 365.948948 -222.393163 \n",
       "L 359.323348 -211.388566 \n",
       "L 352.697729 -212.517992 \n",
       "L 346.072129 -223.506073 \n",
       "L 339.44653 -234.130751 \n",
       "L 332.82093 -244.113217 \n",
       "L 326.19533 -253.233505 \n",
       "L 319.56973 -261.334266 \n",
       "L 312.944111 -268.326123 \n",
       "L 306.318511 -274.18684 \n",
       "L 299.692911 -278.953607 \n",
       "L 293.067312 -282.709936 \n",
       "L 286.441712 -285.569143 \n",
       "L 279.816112 -287.656061 \n",
       "L 273.190493 -289.089164 \n",
       "L 266.564893 -289.964571 \n",
       "L 259.939293 -290.343375 \n",
       "L 253.313693 -290.243222 \n",
       "L 246.688093 -289.634944 \n",
       "L 240.062494 -288.444816 \n",
       "L 233.436875 -286.562854 \n",
       "L 226.811275 -283.857204 \n",
       "L 220.185675 -280.193904 \n",
       "L 213.560075 -275.460738 \n",
       "L 206.934475 -269.592701 \n",
       "L 200.308866 -262.596257 \n",
       "L 193.683266 -254.568904 \n",
       "L 187.057666 -245.710637 \n",
       "L 180.432057 -236.324805 \n",
       "L 173.806457 -226.80676 \n",
       "L 167.180857 -217.621524 \n",
       "L 160.555248 -209.28745 \n",
       "L 153.929648 -208.328425 \n",
       "L 147.304048 -212.473467 \n",
       "L 140.678438 -214.705941 \n",
       "L 134.052839 -214.843912 \n",
       "L 127.427234 -212.869731 \n",
       "L 120.801634 -208.918894 \n",
       "L 114.17603 -203.867624 \n",
       "L 107.550425 -210.668808 \n",
       "L 100.924825 -219.132386 \n",
       "L 94.29922 -228.309495 \n",
       "L 87.673618 -237.710065 \n",
       "L 81.048014 -246.89282 \n",
       "L 74.422411 -255.492137 \n",
       "L 67.796808 -263.23748 \n",
       "L 61.171205 -269.961134 \n",
       "L 54.545602 -275.594439 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p10999bb007)\">\n",
       "     <use xlink:href=\"#m983946f399\" x=\"0\" y=\"309.639375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <defs>\n",
       "     <path id=\"mf6e8c9b567\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p10999bb007)\">\n",
       "     <use xlink:href=\"#mf6e8c9b567\" x=\"356.349693\" y=\"103.2676\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mf6e8c9b567\" x=\"157.258364\" y=\"104.107609\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mf6e8c9b567\" x=\"114.255683\" y=\"106.358136\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 54.545602 102.033489 \n",
       "L 61.171205 102.661746 \n",
       "L 67.796808 103.308657 \n",
       "L 74.422411 103.952097 \n",
       "L 81.048014 104.567104 \n",
       "L 87.673618 105.127442 \n",
       "L 94.29922 105.607438 \n",
       "L 100.924825 105.983939 \n",
       "L 107.550425 106.238181 \n",
       "L 114.17603 106.357364 \n",
       "L 120.801634 106.335739 \n",
       "L 127.427234 106.175058 \n",
       "L 134.052839 105.884383 \n",
       "L 140.678438 105.479256 \n",
       "L 147.304048 104.980321 \n",
       "L 153.929648 104.411613 \n",
       "L 160.555248 103.798673 \n",
       "L 167.180857 103.166726 \n",
       "L 173.806457 102.539095 \n",
       "L 180.432057 101.935978 \n",
       "L 187.057666 101.373681 \n",
       "L 193.683266 100.864316 \n",
       "L 200.308866 100.415915 \n",
       "L 206.934475 100.032895 \n",
       "L 213.560075 99.716757 \n",
       "L 220.185675 99.466896 \n",
       "L 226.811275 99.281425 \n",
       "L 233.436875 99.157911 \n",
       "L 240.062494 99.093938 \n",
       "L 246.688093 99.087467 \n",
       "L 253.313693 99.136951 \n",
       "L 259.939293 99.241219 \n",
       "L 266.564893 99.399151 \n",
       "L 273.190493 99.609181 \n",
       "L 279.816112 99.868712 \n",
       "L 286.441712 100.173512 \n",
       "L 293.067312 100.517188 \n",
       "L 299.692911 100.890832 \n",
       "L 306.318511 101.282908 \n",
       "L 312.944111 101.679454 \n",
       "L 319.56973 102.06461 \n",
       "L 326.19533 102.421457 \n",
       "L 332.82093 102.733097 \n",
       "L 339.44653 102.983889 \n",
       "L 346.072129 103.160679 \n",
       "L 352.697729 103.253897 \n",
       "L 359.323348 103.258387 \n",
       "L 365.948948 103.17387 \n",
       "L 372.574548 103.004954 \n",
       "L 379.200148 102.760697 \n",
       "\" clip-path=\"url(#p10999bb007)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <path d=\"M 54.545602 179.347827 \n",
       "L 61.171205 169.316728 \n",
       "L 67.796808 159.437462 \n",
       "L 74.422411 149.860063 \n",
       "L 81.048014 140.730804 \n",
       "L 87.673618 132.190155 \n",
       "L 94.29922 124.370742 \n",
       "L 100.924825 117.395545 \n",
       "L 107.550425 111.376123 \n",
       "L 114.17603 106.411053 \n",
       "L 120.801634 102.584548 \n",
       "L 127.427234 99.965258 \n",
       "L 134.052839 98.605224 \n",
       "L 140.678438 98.53911 \n",
       "L 147.304048 99.783547 \n",
       "L 153.929648 102.336708 \n",
       "L 160.555248 106.178055 \n",
       "L 167.180857 111.268219 \n",
       "L 173.806457 117.549035 \n",
       "L 180.432057 124.943616 \n",
       "L 187.057666 133.3566 \n",
       "L 193.683266 142.674243 \n",
       "L 200.308866 152.764749 \n",
       "L 206.934475 163.478313 \n",
       "L 213.560075 174.647067 \n",
       "L 220.185675 186.085225 \n",
       "L 226.811275 197.588733 \n",
       "L 233.436875 208.934811 \n",
       "L 240.062494 219.881784 \n",
       "L 246.688093 230.168261 \n",
       "L 253.313693 239.513309 \n",
       "L 259.939293 247.616422 \n",
       "L 266.564893 254.158919 \n",
       "L 273.190493 258.806701 \n",
       "L 279.816112 261.216 \n",
       "L 286.441712 261.043007 \n",
       "L 293.067312 257.959808 \n",
       "L 299.692911 251.678967 \n",
       "L 306.318511 241.989946 \n",
       "L 312.944111 228.811273 \n",
       "L 319.56973 212.261744 \n",
       "L 326.19533 192.753359 \n",
       "L 332.82093 171.103981 \n",
       "L 339.44653 148.660925 \n",
       "L 346.072129 127.410835 \n",
       "L 352.697729 110.027008 \n",
       "L 359.323348 99.769779 \n",
       "L 365.948948 100.112581 \n",
       "L 372.574548 113.936263 \n",
       "L 379.200148 142.165301 \n",
       "\" clip-path=\"url(#p10999bb007)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_17\">\n",
       "    <path d=\"M 54.545602 160.046173 \n",
       "L 61.171205 154.945123 \n",
       "L 67.796808 148.739475 \n",
       "L 74.422411 141.963558 \n",
       "L 81.048014 134.964161 \n",
       "L 87.673618 127.868123 \n",
       "L 94.29922 121.327378 \n",
       "L 100.924825 115.477651 \n",
       "L 107.550425 110.446246 \n",
       "L 114.17603 106.532583 \n",
       "L 120.801634 103.842933 \n",
       "L 127.427234 102.320513 \n",
       "L 134.052839 101.894954 \n",
       "L 140.678438 102.331682 \n",
       "L 147.304048 102.781879 \n",
       "L 153.929648 103.537058 \n",
       "L 160.555248 103.986501 \n",
       "L 167.180857 104.554841 \n",
       "L 173.806457 104.842179 \n",
       "L 180.432057 105.048549 \n",
       "L 187.057666 105.993405 \n",
       "L 193.683266 107.666838 \n",
       "L 200.308866 110.484185 \n",
       "L 206.934475 114.776304 \n",
       "L 213.560075 120.59945 \n",
       "L 220.185675 127.973758 \n",
       "L 226.811275 136.377288 \n",
       "L 233.436875 145.173363 \n",
       "L 240.062494 154.006349 \n",
       "L 246.688093 161.901449 \n",
       "L 253.313693 168.239491 \n",
       "L 259.939293 172.780798 \n",
       "L 266.564893 174.941839 \n",
       "L 273.190493 174.576599 \n",
       "L 279.816112 171.851738 \n",
       "L 286.441712 167.288707 \n",
       "L 293.067312 161.394199 \n",
       "L 299.692911 154.587752 \n",
       "L 306.318511 147.671247 \n",
       "L 312.944111 141.007064 \n",
       "L 319.56973 134.530217 \n",
       "L 326.19533 128.777058 \n",
       "L 332.82093 123.367309 \n",
       "L 339.44653 118.158263 \n",
       "L 346.072129 112.59702 \n",
       "L 352.697729 106.674851 \n",
       "L 359.323348 100.479215 \n",
       "L 365.948948 93.67412 \n",
       "L 372.574548 86.96088 \n",
       "L 379.200148 80.355118 \n",
       "\" clip-path=\"url(#p10999bb007)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_18\">\n",
       "    <path d=\"M 54.545602 77.799526 \n",
       "L 61.171205 73.933156 \n",
       "L 67.796808 72.294098 \n",
       "L 74.422411 72.85376 \n",
       "L 81.048014 75.507613 \n",
       "L 87.673618 80.278929 \n",
       "L 94.29922 86.386835 \n",
       "L 100.924825 93.120683 \n",
       "L 107.550425 100.050046 \n",
       "L 114.17603 106.340673 \n",
       "L 120.801634 111.211292 \n",
       "L 127.427234 114.552954 \n",
       "L 134.052839 115.678074 \n",
       "L 140.678438 114.968469 \n",
       "L 147.304048 111.997407 \n",
       "L 153.929648 107.139798 \n",
       "L 160.555248 100.690932 \n",
       "L 167.180857 92.82502 \n",
       "L 173.806457 83.909718 \n",
       "L 180.432057 74.827931 \n",
       "L 187.057666 65.609515 \n",
       "L 193.683266 57.254572 \n",
       "L 200.308866 50.101387 \n",
       "L 206.934475 44.653263 \n",
       "L 213.560075 41.1786 \n",
       "L 220.185675 40.018603 \n",
       "L 226.811275 41.263162 \n",
       "L 233.436875 44.084613 \n",
       "L 240.062494 48.838992 \n",
       "L 246.688093 54.899475 \n",
       "L 253.313693 61.629117 \n",
       "L 259.939293 68.843918 \n",
       "L 266.564893 75.999026 \n",
       "L 273.190493 83.048451 \n",
       "L 279.816112 89.729903 \n",
       "L 286.441712 95.808488 \n",
       "L 293.067312 101.472004 \n",
       "L 299.692911 106.219495 \n",
       "L 306.318511 110.347355 \n",
       "L 312.944111 113.278069 \n",
       "L 319.56973 115.159363 \n",
       "L 326.19533 116.017219 \n",
       "L 332.82093 115.212536 \n",
       "L 339.44653 113.150325 \n",
       "L 346.072129 110.062183 \n",
       "L 352.697729 105.882135 \n",
       "L 359.323348 100.794846 \n",
       "L 365.948948 95.340961 \n",
       "L 372.574548 89.695462 \n",
       "L 379.200148 84.230873 \n",
       "\" clip-path=\"url(#p10999bb007)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_19\">\n",
       "    <path d=\"M 54.545602 50.112302 \n",
       "L 61.171205 53.911047 \n",
       "L 67.796808 58.949462 \n",
       "L 74.422411 65.321678 \n",
       "L 81.048014 72.89036 \n",
       "L 87.673618 80.962885 \n",
       "L 94.29922 88.916282 \n",
       "L 100.924825 96.233215 \n",
       "L 107.550425 102.066073 \n",
       "L 114.17603 106.265053 \n",
       "L 120.801634 108.494641 \n",
       "L 127.427234 109.288034 \n",
       "L 134.052839 108.519558 \n",
       "L 140.678438 107.154302 \n",
       "L 147.304048 105.798746 \n",
       "L 153.929648 104.808092 \n",
       "L 160.555248 104.76542 \n",
       "L 167.180857 105.519665 \n",
       "L 173.806457 107.143646 \n",
       "L 180.432057 109.320445 \n",
       "L 187.057666 111.848501 \n",
       "L 193.683266 114.179988 \n",
       "L 200.308866 115.965233 \n",
       "L 206.934475 117.482539 \n",
       "L 213.560075 118.333083 \n",
       "L 220.185675 118.764996 \n",
       "L 226.811275 119.078497 \n",
       "L 233.436875 119.694381 \n",
       "L 240.062494 120.370129 \n",
       "L 246.688093 121.506589 \n",
       "L 253.313693 123.211984 \n",
       "L 259.939293 125.302025 \n",
       "L 266.564893 127.750436 \n",
       "L 273.190493 130.667829 \n",
       "L 279.816112 133.547285 \n",
       "L 286.441712 136.287567 \n",
       "L 293.067312 138.642457 \n",
       "L 299.692911 140.365734 \n",
       "L 306.318511 141.243668 \n",
       "L 312.944111 140.638359 \n",
       "L 319.56973 138.842648 \n",
       "L 326.19533 135.263812 \n",
       "L 332.82093 130.126333 \n",
       "L 339.44653 123.660472 \n",
       "L 346.072129 116.136677 \n",
       "L 352.697729 107.924281 \n",
       "L 359.323348 99.657368 \n",
       "L 365.948948 91.718396 \n",
       "L 372.574548 84.677132 \n",
       "L 379.200148 78.805372 \n",
       "\" clip-path=\"url(#p10999bb007)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_20\">\n",
       "    <path d=\"M 54.545602 110.187222 \n",
       "L 61.171205 104.792334 \n",
       "L 67.796808 100.706693 \n",
       "L 74.422411 98.479063 \n",
       "L 81.048014 98.010663 \n",
       "L 87.673618 98.967556 \n",
       "L 94.29922 100.63749 \n",
       "L 100.924825 102.709614 \n",
       "L 107.550425 104.754672 \n",
       "L 114.17603 106.43172 \n",
       "L 120.801634 107.448378 \n",
       "L 127.427234 108.154243 \n",
       "L 134.052839 108.080945 \n",
       "L 140.678438 107.6484 \n",
       "L 147.304048 106.657411 \n",
       "L 153.929648 105.206226 \n",
       "L 160.555248 102.824306 \n",
       "L 167.180857 100.139562 \n",
       "L 173.806457 97.102474 \n",
       "L 180.432057 93.42826 \n",
       "L 187.057666 89.719194 \n",
       "L 193.683266 86.27795 \n",
       "L 200.308866 83.430153 \n",
       "L 206.934475 81.602911 \n",
       "L 213.560075 80.822415 \n",
       "L 220.185675 81.187807 \n",
       "L 226.811275 82.509412 \n",
       "L 233.436875 84.698565 \n",
       "L 240.062494 87.043264 \n",
       "L 246.688093 89.294185 \n",
       "L 253.313693 90.958475 \n",
       "L 259.939293 91.711735 \n",
       "L 266.564893 91.517927 \n",
       "L 273.190493 90.69445 \n",
       "L 279.816112 88.864044 \n",
       "L 286.441712 86.854182 \n",
       "L 293.067312 84.663105 \n",
       "L 299.692911 82.938076 \n",
       "L 306.318511 82.058478 \n",
       "L 312.944111 82.281455 \n",
       "L 319.56973 83.638692 \n",
       "L 326.19533 86.216433 \n",
       "L 332.82093 89.476574 \n",
       "L 339.44653 93.397723 \n",
       "L 346.072129 97.438014 \n",
       "L 352.697729 101.434229 \n",
       "L 359.323348 104.989345 \n",
       "L 365.948948 108.279635 \n",
       "L 372.574548 110.703108 \n",
       "L 379.200148 113.182045 \n",
       "\" clip-path=\"url(#p10999bb007)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_21\">\n",
       "    <path d=\"M 54.545602 69.271649 \n",
       "L 61.171205 72.751644 \n",
       "L 67.796808 77.025701 \n",
       "L 74.422411 81.517589 \n",
       "L 81.048014 86.468846 \n",
       "L 87.673618 91.107314 \n",
       "L 94.29922 95.590239 \n",
       "L 100.924825 99.829777 \n",
       "L 107.550425 103.299056 \n",
       "L 114.17603 106.238953 \n",
       "L 120.801634 108.517018 \n",
       "L 127.427234 109.920631 \n",
       "L 134.052839 110.169345 \n",
       "L 140.678438 109.604474 \n",
       "L 147.304048 108.049391 \n",
       "L 153.929648 105.705644 \n",
       "L 160.555248 102.787663 \n",
       "L 167.180857 99.843141 \n",
       "L 173.806457 97.37025 \n",
       "L 180.432057 95.614946 \n",
       "L 187.057666 94.87179 \n",
       "L 193.683266 94.834459 \n",
       "L 200.308866 95.872636 \n",
       "L 206.934475 97.527363 \n",
       "L 213.560075 99.461865 \n",
       "L 220.185675 101.15196 \n",
       "L 226.811275 102.758836 \n",
       "L 233.436875 103.569784 \n",
       "L 240.062494 104.062752 \n",
       "L 246.688093 104.346214 \n",
       "L 253.313693 104.402459 \n",
       "L 259.939293 104.417562 \n",
       "L 266.564893 104.594114 \n",
       "L 273.190493 105.173299 \n",
       "L 279.816112 106.08824 \n",
       "L 286.441712 107.090528 \n",
       "L 293.067312 108.530656 \n",
       "L 299.692911 110.150265 \n",
       "L 306.318511 111.67009 \n",
       "L 312.944111 112.917752 \n",
       "L 319.56973 113.819503 \n",
       "L 326.19533 114.199257 \n",
       "L 332.82093 113.731078 \n",
       "L 339.44653 112.254257 \n",
       "L 346.072129 109.817988 \n",
       "L 352.697729 105.928447 \n",
       "L 359.323348 101.260712 \n",
       "L 365.948948 95.766854 \n",
       "L 372.574548 90.220724 \n",
       "L 379.200148 84.775236 \n",
       "\" clip-path=\"url(#p10999bb007)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_22\">\n",
       "    <path d=\"M 54.545602 165.752137 \n",
       "L 61.171205 163.02941 \n",
       "L 67.796808 157.771065 \n",
       "L 74.422411 150.572041 \n",
       "L 81.048014 142.127244 \n",
       "L 87.673618 133.478608 \n",
       "L 94.29922 124.971254 \n",
       "L 100.924825 117.515889 \n",
       "L 107.550425 111.256957 \n",
       "L 114.17603 106.504487 \n",
       "L 120.801634 103.626672 \n",
       "L 127.427234 102.097789 \n",
       "L 134.052839 101.719927 \n",
       "L 140.678438 102.228831 \n",
       "L 147.304048 103.040288 \n",
       "L 153.929648 103.627605 \n",
       "L 160.555248 103.514135 \n",
       "L 167.180857 102.694265 \n",
       "L 173.806457 100.298011 \n",
       "L 180.432057 96.761465 \n",
       "L 187.057666 91.838132 \n",
       "L 193.683266 86.001901 \n",
       "L 200.308866 79.321447 \n",
       "L 206.934475 72.243754 \n",
       "L 213.560075 65.443295 \n",
       "L 220.185675 59.341332 \n",
       "L 226.811275 54.037239 \n",
       "L 233.436875 49.93305 \n",
       "L 240.062494 47.220834 \n",
       "L 246.688093 45.642192 \n",
       "L 253.313693 45.519742 \n",
       "L 259.939293 46.075276 \n",
       "L 266.564893 47.460976 \n",
       "L 273.190493 49.435062 \n",
       "L 279.816112 51.438993 \n",
       "L 286.441712 53.83013 \n",
       "L 293.067312 55.97267 \n",
       "L 299.692911 58.647024 \n",
       "L 306.318511 61.263665 \n",
       "L 312.944111 64.137863 \n",
       "L 319.56973 67.512632 \n",
       "L 326.19533 71.771488 \n",
       "L 332.82093 76.71633 \n",
       "L 339.44653 83.063807 \n",
       "L 346.072129 90.381681 \n",
       "L 352.697729 98.406112 \n",
       "L 359.323348 107.023562 \n",
       "L 365.948948 115.762929 \n",
       "L 372.574548 123.496584 \n",
       "L 379.200148 130.1274 \n",
       "\" clip-path=\"url(#p10999bb007)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_23\">\n",
       "    <path d=\"M 54.545602 100.421963 \n",
       "L 61.171205 103.099585 \n",
       "L 67.796808 105.821994 \n",
       "L 74.422411 108.160012 \n",
       "L 81.048014 109.488297 \n",
       "L 87.673618 110.093239 \n",
       "L 94.29922 109.874557 \n",
       "L 100.924825 109.057829 \n",
       "L 107.550425 107.747958 \n",
       "L 114.17603 106.399257 \n",
       "L 120.801634 105.108407 \n",
       "L 127.427234 104.194875 \n",
       "L 134.052839 103.789616 \n",
       "L 140.678438 103.553466 \n",
       "L 147.304048 103.9473 \n",
       "L 153.929648 104.008132 \n",
       "L 160.555248 103.990869 \n",
       "L 167.180857 103.737588 \n",
       "L 173.806457 102.603417 \n",
       "L 180.432057 100.554603 \n",
       "L 187.057666 97.666403 \n",
       "L 193.683266 94.142268 \n",
       "L 200.308866 89.873854 \n",
       "L 206.934475 85.465328 \n",
       "L 213.560075 81.223848 \n",
       "L 220.185675 77.138839 \n",
       "L 226.811275 73.716983 \n",
       "L 233.436875 70.99498 \n",
       "L 240.062494 69.031456 \n",
       "L 246.688093 67.792883 \n",
       "L 253.313693 67.255707 \n",
       "L 259.939293 67.15554 \n",
       "L 266.564893 67.60263 \n",
       "L 273.190493 68.701844 \n",
       "L 279.816112 70.348408 \n",
       "L 286.441712 72.462141 \n",
       "L 293.067312 75.41831 \n",
       "L 299.692911 78.996984 \n",
       "L 306.318511 82.999732 \n",
       "L 312.944111 87.390779 \n",
       "L 319.56973 91.696221 \n",
       "L 326.19533 95.668326 \n",
       "L 332.82093 98.806416 \n",
       "L 339.44653 101.027867 \n",
       "L 346.072129 102.503854 \n",
       "L 352.697729 103.059401 \n",
       "L 359.323348 103.157282 \n",
       "L 365.948948 102.962916 \n",
       "L 372.574548 103.331531 \n",
       "L 379.200148 104.062164 \n",
       "\" clip-path=\"url(#p10999bb007)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_24\">\n",
       "    <path d=\"M 54.545602 143.624254 \n",
       "L 61.171205 143.991404 \n",
       "L 67.796808 143.111142 \n",
       "L 74.422411 140.431041 \n",
       "L 81.048014 136.354257 \n",
       "L 87.673618 131.404585 \n",
       "L 94.29922 125.255863 \n",
       "L 100.924825 118.65715 \n",
       "L 107.550425 112.211404 \n",
       "L 114.17603 106.390763 \n",
       "L 120.801634 101.930125 \n",
       "L 127.427234 98.689156 \n",
       "L 134.052839 96.958594 \n",
       "L 140.678438 97.178421 \n",
       "L 147.304048 98.92772 \n",
       "L 153.929648 102.201168 \n",
       "L 160.555248 106.35093 \n",
       "L 167.180857 111.405812 \n",
       "L 173.806457 116.693345 \n",
       "L 180.432057 121.635743 \n",
       "L 187.057666 126.007683 \n",
       "L 193.683266 129.399253 \n",
       "L 200.308866 131.187453 \n",
       "L 206.934475 131.67184 \n",
       "L 213.560075 130.416286 \n",
       "L 220.185675 127.513998 \n",
       "L 226.811275 122.984282 \n",
       "L 233.436875 117.439334 \n",
       "L 240.062494 110.73803 \n",
       "L 246.688093 103.566436 \n",
       "L 253.313693 96.41669 \n",
       "L 259.939293 89.915786 \n",
       "L 266.564893 84.109401 \n",
       "L 273.190493 79.756461 \n",
       "L 279.816112 76.593237 \n",
       "L 286.441712 75.045533 \n",
       "L 293.067312 74.511485 \n",
       "L 299.692911 75.497245 \n",
       "L 306.318511 76.979015 \n",
       "L 312.944111 79.305452 \n",
       "L 319.56973 82.182529 \n",
       "L 326.19533 85.59338 \n",
       "L 332.82093 89.081343 \n",
       "L 339.44653 92.979627 \n",
       "L 346.072129 96.863951 \n",
       "L 352.697729 100.884343 \n",
       "L 359.323348 104.700411 \n",
       "L 365.948948 108.338643 \n",
       "L 372.574548 111.376189 \n",
       "L 379.200148 114.123001 \n",
       "\" clip-path=\"url(#p10999bb007)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_25\">\n",
       "    <path d=\"M 54.545602 107.880159 \n",
       "L 61.171205 105.503562 \n",
       "L 67.796808 104.310081 \n",
       "L 74.422411 104.003807 \n",
       "L 81.048014 104.11607 \n",
       "L 87.673618 104.424363 \n",
       "L 94.29922 105.057834 \n",
       "L 100.924825 105.478537 \n",
       "L 107.550425 106.088897 \n",
       "L 114.17603 106.434619 \n",
       "L 120.801634 106.456226 \n",
       "L 127.427234 106.19117 \n",
       "L 134.052839 105.955084 \n",
       "L 140.678438 105.400758 \n",
       "L 147.304048 104.880389 \n",
       "L 153.929648 104.439285 \n",
       "L 160.555248 103.899073 \n",
       "L 167.180857 103.304057 \n",
       "L 173.806457 102.707391 \n",
       "L 180.432057 101.423152 \n",
       "L 187.057666 99.889521 \n",
       "L 193.683266 97.754595 \n",
       "L 200.308866 94.998032 \n",
       "L 206.934475 92.280089 \n",
       "L 213.560075 89.097357 \n",
       "L 220.185675 86.218859 \n",
       "L 226.811275 83.77586 \n",
       "L 233.436875 81.703044 \n",
       "L 240.062494 80.691282 \n",
       "L 246.688093 80.762597 \n",
       "L 253.313693 81.705216 \n",
       "L 259.939293 83.869753 \n",
       "L 266.564893 86.992658 \n",
       "L 273.190493 91.045175 \n",
       "L 279.816112 95.849144 \n",
       "L 286.441712 101.04456 \n",
       "L 293.067312 106.32642 \n",
       "L 299.692911 111.346359 \n",
       "L 306.318511 115.624066 \n",
       "L 312.944111 118.400774 \n",
       "L 319.56973 120.173272 \n",
       "L 326.19533 120.081682 \n",
       "L 332.82093 118.396532 \n",
       "L 339.44653 115.424079 \n",
       "L 346.072129 111.236249 \n",
       "L 352.697729 106.385127 \n",
       "L 359.323348 101.061313 \n",
       "L 365.948948 95.664254 \n",
       "L 372.574548 90.617129 \n",
       "L 379.200148 85.611644 \n",
       "\" clip-path=\"url(#p10999bb007)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_26\">\n",
       "    <path d=\"M 54.545602 110.416523 \n",
       "L 61.171205 115.325781 \n",
       "L 67.796808 119.204159 \n",
       "L 74.422411 121.738773 \n",
       "L 81.048014 122.557987 \n",
       "L 87.673618 121.44949 \n",
       "L 94.29922 118.89325 \n",
       "L 100.924825 115.294916 \n",
       "L 107.550425 110.804595 \n",
       "L 114.17603 106.40106 \n",
       "L 120.801634 102.458923 \n",
       "L 127.427234 99.71037 \n",
       "L 134.052839 98.212093 \n",
       "L 140.678438 98.106086 \n",
       "L 147.304048 99.619147 \n",
       "L 153.929648 102.428474 \n",
       "L 160.555248 105.934503 \n",
       "L 167.180857 109.758679 \n",
       "L 173.806457 113.584453 \n",
       "L 180.432057 117.107089 \n",
       "L 187.057666 119.921571 \n",
       "L 193.683266 121.738914 \n",
       "L 200.308866 122.835929 \n",
       "L 206.934475 122.697543 \n",
       "L 213.560075 122.073595 \n",
       "L 220.185675 121.025504 \n",
       "L 226.811275 119.852517 \n",
       "L 233.436875 118.58923 \n",
       "L 240.062494 117.397299 \n",
       "L 246.688093 116.541481 \n",
       "L 253.313693 116.122434 \n",
       "L 259.939293 116.075962 \n",
       "L 266.564893 116.628698 \n",
       "L 273.190493 117.719895 \n",
       "L 279.816112 119.415282 \n",
       "L 286.441712 121.326521 \n",
       "L 293.067312 123.701999 \n",
       "L 299.692911 125.757238 \n",
       "L 306.318511 127.392921 \n",
       "L 312.944111 127.911984 \n",
       "L 319.56973 127.485366 \n",
       "L 326.19533 125.399062 \n",
       "L 332.82093 122.072657 \n",
       "L 339.44653 117.428429 \n",
       "L 346.072129 112.178717 \n",
       "L 352.697729 106.518712 \n",
       "L 359.323348 100.899862 \n",
       "L 365.948948 95.896234 \n",
       "L 372.574548 92.093791 \n",
       "L 379.200148 89.683289 \n",
       "\" clip-path=\"url(#p10999bb007)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_27\"/>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 261.478006 \n",
       "L 38.312875 16.871874 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 273.312 \n",
       "L 379.200148 273.312 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_28\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#mf6e8c9b567\" x=\"55.032875\" y=\"194.65925\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 197.73925) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_29\">\n",
       "     <path d=\"M 46.232875 207.24325 \n",
       "L 55.032875 207.24325 \n",
       "L 63.832875 207.24325 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 210.32325) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 46.232875 224.48025 \n",
       "L 63.832875 224.48025 \n",
       "L 63.832875 218.32025 \n",
       "L 46.232875 218.32025 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 224.48025) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 46.232875 238.64825 \n",
       "L 63.832875 238.64825 \n",
       "L 63.832875 232.48825 \n",
       "L 46.232875 232.48825 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 238.64825) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_30\">\n",
       "     <path d=\"M 46.232875 248.115125 \n",
       "L 55.032875 248.115125 \n",
       "L 63.832875 248.115125 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 251.195125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_31\">\n",
       "     <path d=\"M 46.232875 260.563 \n",
       "L 55.032875 260.563 \n",
       "L 63.832875 260.563 \n",
       "\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- Posterior samples -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 263.643) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-50\" d=\"M 494 0 \n",
       "L 494 4581 \n",
       "L 2222 4581 \n",
       "Q 2678 4581 2919 4538 \n",
       "Q 3256 4481 3484 4323 \n",
       "Q 3713 4166 3852 3881 \n",
       "Q 3991 3597 3991 3256 \n",
       "Q 3991 2672 3619 2267 \n",
       "Q 3247 1863 2275 1863 \n",
       "L 1100 1863 \n",
       "L 1100 0 \n",
       "L 494 0 \n",
       "z\n",
       "M 1100 2403 \n",
       "L 2284 2403 \n",
       "Q 2872 2403 3119 2622 \n",
       "Q 3366 2841 3366 3238 \n",
       "Q 3366 3525 3220 3729 \n",
       "Q 3075 3934 2838 4000 \n",
       "Q 2684 4041 2272 4041 \n",
       "L 1100 4041 \n",
       "L 1100 2403 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-50\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"66.699219\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"122.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"172.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"255.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"289.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"311.230469\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"366.845703\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"400.146484\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"477.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"533.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" x=\"616.845703\"/>\n",
       "      <use xlink:href=\"#ArialMT-6c\" x=\"672.460938\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"694.677734\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"750.292969\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p10999bb007\">\n",
       "   <rect x=\"38.312875\" y=\"7.2\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "train_x = torch.from_numpy(X).float()\n",
    "train_y = torch.from_numpy(Y).float()\n",
    "model = ExactGP(train_x, train_y)\n",
    "\n",
    "# It is not a good idea to train the model when we don't have enough data\n",
    "# So we fix the hyperparameters to something reasonable\n",
    "model.covar_module.base_kernel.lengthscale = 0.15\n",
    "model.covar_module.outputscale = 4.0\n",
    "model.likelihood.noise = 1e-4\n",
    "model.eval()\n",
    "\n",
    "plot_1d_regression(\n",
    "    torch.from_numpy(x).float(),\n",
    "    model,\n",
    "    f_true=f\n",
    ");"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Help on method set_train_data in module gpytorch.models.exact_gp:\n",
      "\n",
      "set_train_data(inputs=None, targets=None, strict=True) method of __main__.ExactGP instance\n",
      "    Set training data (does not re-fit model hyper-parameters).\n",
      "    \n",
      "    :param torch.Tensor inputs: The new training inputs.\n",
      "    :param torch.Tensor targets: The new training targets.\n",
      "    :param bool strict: (default True) If `True`, the new inputs and\n",
      "        targets must have the same shape, dtype, and device\n",
      "        as the current inputs and targets. Otherwise, any shape/dtype/device are allowed.\n",
      "\n"
     ]
    }
   ],
   "source": [
    "help(model.set_train_data)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Now, the question is this: \"Where should we evaluate the function next if our goal is to maximize the function?\"\n",
    "Let's start with the naive assumption that we should evaluate the function at the point that maximizes the Gaussian process posterior mean, i.e., wherever is the max of the thick blue line.\n",
    "In other words, the information acquisition function is the posterior mean of the Gaussian process.\n",
    "Let's see what happens."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [],
   "source": [
    "def maximize_naive(f, model, X_design, max_it=6):\n",
    "    \"\"\"\n",
    "    Optimize f using a limited number of evaluations.\n",
    "    \n",
    "    Arguments\n",
    "    f        --  The function to optimize.\n",
    "    model    --  A Gaussian process model to use for representing our state of knowledge.\n",
    "    X_design --  The set of candidate points for identifying the maximum.\n",
    "    max_it   --  The maximum number of iterations.\n",
    "    \"\"\"\n",
    "    for count in range(max_it):\n",
    "        model.train()\n",
    "        model.eval()\n",
    "        m = model(X_design).mean.detach()\n",
    "        i = np.argmax(m)\n",
    "        \n",
    "        new_x = X_design[i:(i+1)].float()\n",
    "        new_y = f(new_x)\n",
    "        train_x = torch.cat([model.train_inputs[0], new_x[:, None]])\n",
    "        train_y = torch.cat([model.train_targets, new_y])\n",
    "        model.set_train_data(train_x, train_y, strict=False)\n",
    "        model.train()\n",
    "        model.eval()\n",
    "        \n",
    "        fig, ax = plt.subplots()\n",
    "        plot_1d_regression(\n",
    "            X_design,\n",
    "            model,\n",
    "            ax=ax,\n",
    "            f_true=f,\n",
    "            num_samples=0\n",
    "        )\n",
    "        ax.plot(x[i], f(x[i]), 'go', label='Next observation')\n",
    "        ax.set_title('BGO iteration #{0:d}'.format(count+1))\n",
    "        plt.legend(loc='best', frameon=False)\n",
    "        sns.despine(trim=True);"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {
    "tags": [
     "hide-output"
    ]
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"402.632875pt\" height=\"322.510875pt\" viewBox=\"0 0 402.632875 322.510875\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:17:14.626829</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.510875 \n",
       "L 402.632875 322.510875 \n",
       "L 402.632875 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 286.1835 \n",
       "L 395.432875 286.1835 \n",
       "L 395.432875 20.0715 \n",
       "L 38.312875 20.0715 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"mffae21bace\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mffae21bace\" x=\"54.545602\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mffae21bace\" x=\"119.476511\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mffae21bace\" x=\"184.40742\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mffae21bace\" x=\"249.33833\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mffae21bace\" x=\"314.269239\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mffae21bace\" x=\"379.200148\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 313.402875) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"md047212d61\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#md047212d61\" x=\"38.312875\" y=\"274.376352\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 277.52579) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md047212d61\" x=\"38.312875\" y=\"229.43151\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 232.580948) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md047212d61\" x=\"38.312875\" y=\"184.486669\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 187.636106) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md047212d61\" x=\"38.312875\" y=\"139.541827\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 142.691265) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md047212d61\" x=\"38.312875\" y=\"94.596986\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 97.746423) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md047212d61\" x=\"38.312875\" y=\"49.652144\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 52.801582) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_14\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.0075) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m5aba40174e\" d=\"M 54.545602 -290.342025 \n",
       "L 54.545602 -140.774676 \n",
       "L 61.171205 -144.957319 \n",
       "L 67.796808 -150.583836 \n",
       "L 74.422411 -157.714444 \n",
       "L 81.048014 -166.290523 \n",
       "L 87.673618 -176.114277 \n",
       "L 94.29922 -186.840357 \n",
       "L 100.924825 -197.982339 \n",
       "L 107.550425 -208.93284 \n",
       "L 114.17603 -218.656256 \n",
       "L 120.801634 -215.544128 \n",
       "L 127.427234 -213.768386 \n",
       "L 134.052839 -213.74462 \n",
       "L 140.678438 -215.175484 \n",
       "L 147.304048 -217.577739 \n",
       "L 153.929648 -220.309821 \n",
       "L 160.555248 -215.909903 \n",
       "L 167.180857 -202.284842 \n",
       "L 173.806457 -186.203658 \n",
       "L 180.432057 -168.450103 \n",
       "L 187.057666 -149.912434 \n",
       "L 193.683266 -131.540327 \n",
       "L 200.308866 -114.28876 \n",
       "L 206.934475 -99.061439 \n",
       "L 213.560075 -86.657894 \n",
       "L 220.185675 -77.72667 \n",
       "L 226.811275 -72.727964 \n",
       "L 233.436875 -71.907131 \n",
       "L 240.062494 -75.280193 \n",
       "L 246.688093 -82.206416 \n",
       "L 253.313693 -71.50345 \n",
       "L 259.939293 -63.543464 \n",
       "L 266.564893 -59.029085 \n",
       "L 273.190493 -58.042653 \n",
       "L 279.816112 -60.492848 \n",
       "L 286.441712 -66.146883 \n",
       "L 293.067312 -74.668746 \n",
       "L 299.692911 -85.658452 \n",
       "L 306.318511 -98.687783 \n",
       "L 312.944111 -113.327788 \n",
       "L 319.56973 -129.167081 \n",
       "L 326.19533 -145.82021 \n",
       "L 332.82093 -162.928766 \n",
       "L 339.44653 -180.158211 \n",
       "L 346.072129 -197.193329 \n",
       "L 352.697729 -213.731147 \n",
       "L 359.323348 -218.702078 \n",
       "L 365.948948 -209.567538 \n",
       "L 372.574548 -200.004381 \n",
       "L 379.200148 -190.485857 \n",
       "L 379.200148 -269.949269 \n",
       "L 379.200148 -269.949269 \n",
       "L 372.574548 -257.821927 \n",
       "L 365.948948 -244.29477 \n",
       "L 359.323348 -229.545042 \n",
       "L 352.697729 -226.952166 \n",
       "L 346.072129 -233.699644 \n",
       "L 339.44653 -238.485336 \n",
       "L 332.82093 -240.849966 \n",
       "L 326.19533 -240.431473 \n",
       "L 319.56973 -236.990503 \n",
       "L 312.944111 -230.434727 \n",
       "L 306.318511 -220.835145 \n",
       "L 299.692911 -208.433475 \n",
       "L 293.067312 -193.639722 \n",
       "L 286.441712 -177.019415 \n",
       "L 279.816112 -159.271449 \n",
       "L 273.190493 -141.195433 \n",
       "L 266.564893 -123.650732 \n",
       "L 259.939293 -107.508913 \n",
       "L 253.313693 -93.603372 \n",
       "L 246.688093 -83.105933 \n",
       "L 240.062494 -96.52644 \n",
       "L 233.436875 -112.4654 \n",
       "L 226.811275 -129.71655 \n",
       "L 220.185675 -147.418294 \n",
       "L 213.560075 -164.688506 \n",
       "L 206.934475 -180.692361 \n",
       "L 200.308866 -194.710192 \n",
       "L 193.683266 -206.197173 \n",
       "L 187.057666 -214.828205 \n",
       "L 180.432057 -220.523008 \n",
       "L 173.806457 -223.44794 \n",
       "L 167.180857 -223.995466 \n",
       "L 160.555248 -222.751627 \n",
       "L 153.929648 -226.57275 \n",
       "L 147.304048 -233.703948 \n",
       "L 140.678438 -237.221711 \n",
       "L 134.052839 -237.160988 \n",
       "L 127.427234 -233.78655 \n",
       "L 120.801634 -227.555119 \n",
       "L 114.17603 -219.583959 \n",
       "L 107.550425 -224.647393 \n",
       "L 100.924825 -231.607863 \n",
       "L 94.29922 -239.752738 \n",
       "L 87.673618 -248.648839 \n",
       "L 81.048014 -257.847899 \n",
       "L 74.422411 -266.929469 \n",
       "L 67.796808 -275.536548 \n",
       "L 61.171205 -283.398732 \n",
       "L 54.545602 -290.342025 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pc88061c8ed)\">\n",
       "     <use xlink:href=\"#m5aba40174e\" x=\"0\" y=\"322.510875\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m8aaedd79fa\" d=\"M 54.545602 -140.774676 \n",
       "L 54.545602 -140.773326 \n",
       "L 61.171205 -144.955861 \n",
       "L 67.796808 -150.582218 \n",
       "L 74.422411 -157.712595 \n",
       "L 81.048014 -166.288315 \n",
       "L 87.673618 -176.111497 \n",
       "L 94.29922 -186.836537 \n",
       "L 100.924825 -197.976333 \n",
       "L 107.550425 -208.919994 \n",
       "L 114.17603 -218.474227 \n",
       "L 120.801634 -215.527334 \n",
       "L 127.427234 -213.7583 \n",
       "L 134.052839 -213.735997 \n",
       "L 140.678438 -215.166325 \n",
       "L 147.304048 -217.565222 \n",
       "L 153.929648 -220.277731 \n",
       "L 160.555248 -215.880503 \n",
       "L 167.180857 -202.275541 \n",
       "L 173.806457 -186.198235 \n",
       "L 180.432057 -168.446224 \n",
       "L 187.057666 -149.909321 \n",
       "L 193.683266 -131.537616 \n",
       "L 200.308866 -114.286241 \n",
       "L 206.934475 -99.058963 \n",
       "L 213.560075 -86.6553 \n",
       "L 220.185675 -77.723766 \n",
       "L 226.811275 -72.724417 \n",
       "L 233.436875 -71.902149 \n",
       "L 240.062494 -75.270689 \n",
       "L 246.688093 -82.020338 \n",
       "L 253.313693 -71.49431 \n",
       "L 259.939293 -63.538878 \n",
       "L 266.564893 -59.025967 \n",
       "L 273.190493 -58.04022 \n",
       "L 279.816112 -60.490801 \n",
       "L 286.441712 -66.145061 \n",
       "L 293.067312 -74.667053 \n",
       "L 299.692911 -85.656813 \n",
       "L 306.318511 -98.686133 \n",
       "L 312.944111 -113.326073 \n",
       "L 319.56973 -129.165206 \n",
       "L 326.19533 -145.818078 \n",
       "L 332.82093 -162.926173 \n",
       "L 339.44653 -180.154744 \n",
       "L 346.072129 -197.187798 \n",
       "L 352.697729 -213.715885 \n",
       "L 359.323348 -218.68348 \n",
       "L 365.948948 -209.561719 \n",
       "L 372.574548 -200.000887 \n",
       "L 379.200148 -190.483315 \n",
       "L 379.200148 -190.485857 \n",
       "L 379.200148 -190.485857 \n",
       "L 372.574548 -200.004381 \n",
       "L 365.948948 -209.567538 \n",
       "L 359.323348 -218.702078 \n",
       "L 352.697729 -213.731147 \n",
       "L 346.072129 -197.193329 \n",
       "L 339.44653 -180.158211 \n",
       "L 332.82093 -162.928766 \n",
       "L 326.19533 -145.82021 \n",
       "L 319.56973 -129.167081 \n",
       "L 312.944111 -113.327788 \n",
       "L 306.318511 -98.687783 \n",
       "L 299.692911 -85.658452 \n",
       "L 293.067312 -74.668746 \n",
       "L 286.441712 -66.146883 \n",
       "L 279.816112 -60.492848 \n",
       "L 273.190493 -58.042653 \n",
       "L 266.564893 -59.029085 \n",
       "L 259.939293 -63.543464 \n",
       "L 253.313693 -71.50345 \n",
       "L 246.688093 -82.206416 \n",
       "L 240.062494 -75.280193 \n",
       "L 233.436875 -71.907131 \n",
       "L 226.811275 -72.727964 \n",
       "L 220.185675 -77.72667 \n",
       "L 213.560075 -86.657894 \n",
       "L 206.934475 -99.061439 \n",
       "L 200.308866 -114.28876 \n",
       "L 193.683266 -131.540327 \n",
       "L 187.057666 -149.912434 \n",
       "L 180.432057 -168.450103 \n",
       "L 173.806457 -186.203658 \n",
       "L 167.180857 -202.284842 \n",
       "L 160.555248 -215.909903 \n",
       "L 153.929648 -220.309821 \n",
       "L 147.304048 -217.577739 \n",
       "L 140.678438 -215.175484 \n",
       "L 134.052839 -213.74462 \n",
       "L 127.427234 -213.768386 \n",
       "L 120.801634 -215.544128 \n",
       "L 114.17603 -218.656256 \n",
       "L 107.550425 -208.93284 \n",
       "L 100.924825 -197.982339 \n",
       "L 94.29922 -186.840357 \n",
       "L 87.673618 -176.114277 \n",
       "L 81.048014 -166.290523 \n",
       "L 74.422411 -157.714444 \n",
       "L 67.796808 -150.583836 \n",
       "L 61.171205 -144.957319 \n",
       "L 54.545602 -140.774676 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pc88061c8ed)\">\n",
       "     <use xlink:href=\"#m8aaedd79fa\" x=\"0\" y=\"322.510875\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m11983e82db\" d=\"M 54.545602 -290.343375 \n",
       "L 54.545602 -290.342025 \n",
       "L 61.171205 -283.398732 \n",
       "L 67.796808 -275.536548 \n",
       "L 74.422411 -266.929469 \n",
       "L 81.048014 -257.847899 \n",
       "L 87.673618 -248.648839 \n",
       "L 94.29922 -239.752738 \n",
       "L 100.924825 -231.607863 \n",
       "L 107.550425 -224.647393 \n",
       "L 114.17603 -219.583959 \n",
       "L 120.801634 -227.555119 \n",
       "L 127.427234 -233.78655 \n",
       "L 134.052839 -237.160988 \n",
       "L 140.678438 -237.221711 \n",
       "L 147.304048 -233.703948 \n",
       "L 153.929648 -226.57275 \n",
       "L 160.555248 -222.751627 \n",
       "L 167.180857 -223.995466 \n",
       "L 173.806457 -223.44794 \n",
       "L 180.432057 -220.523008 \n",
       "L 187.057666 -214.828205 \n",
       "L 193.683266 -206.197173 \n",
       "L 200.308866 -194.710192 \n",
       "L 206.934475 -180.692361 \n",
       "L 213.560075 -164.688506 \n",
       "L 220.185675 -147.418294 \n",
       "L 226.811275 -129.71655 \n",
       "L 233.436875 -112.4654 \n",
       "L 240.062494 -96.52644 \n",
       "L 246.688093 -83.105933 \n",
       "L 253.313693 -93.603372 \n",
       "L 259.939293 -107.508913 \n",
       "L 266.564893 -123.650732 \n",
       "L 273.190493 -141.195433 \n",
       "L 279.816112 -159.271449 \n",
       "L 286.441712 -177.019415 \n",
       "L 293.067312 -193.639722 \n",
       "L 299.692911 -208.433475 \n",
       "L 306.318511 -220.835145 \n",
       "L 312.944111 -230.434727 \n",
       "L 319.56973 -236.990503 \n",
       "L 326.19533 -240.431473 \n",
       "L 332.82093 -240.849966 \n",
       "L 339.44653 -238.485336 \n",
       "L 346.072129 -233.699644 \n",
       "L 352.697729 -226.952166 \n",
       "L 359.323348 -229.545042 \n",
       "L 365.948948 -244.29477 \n",
       "L 372.574548 -257.821927 \n",
       "L 379.200148 -269.949269 \n",
       "L 379.200148 -269.951812 \n",
       "L 379.200148 -269.951812 \n",
       "L 372.574548 -257.82542 \n",
       "L 365.948948 -244.300586 \n",
       "L 359.323348 -229.563641 \n",
       "L 352.697729 -226.967427 \n",
       "L 346.072129 -233.705176 \n",
       "L 339.44653 -238.4888 \n",
       "L 332.82093 -240.852559 \n",
       "L 326.19533 -240.433606 \n",
       "L 319.56973 -236.992378 \n",
       "L 312.944111 -230.436453 \n",
       "L 306.318511 -220.836801 \n",
       "L 299.692911 -208.43512 \n",
       "L 293.067312 -193.64142 \n",
       "L 286.441712 -177.021237 \n",
       "L 279.816112 -159.273496 \n",
       "L 273.190493 -141.19786 \n",
       "L 266.564893 -123.653851 \n",
       "L 259.939293 -107.5135 \n",
       "L 253.313693 -93.612513 \n",
       "L 246.688093 -83.292011 \n",
       "L 240.062494 -96.535945 \n",
       "L 233.436875 -112.470383 \n",
       "L 226.811275 -129.720096 \n",
       "L 220.185675 -147.421198 \n",
       "L 213.560075 -164.6911 \n",
       "L 206.934475 -180.694836 \n",
       "L 200.308866 -194.712705 \n",
       "L 193.683266 -206.199879 \n",
       "L 187.057666 -214.831318 \n",
       "L 180.432057 -220.526887 \n",
       "L 173.806457 -223.453363 \n",
       "L 167.180857 -224.004766 \n",
       "L 160.555248 -222.781026 \n",
       "L 153.929648 -226.60484 \n",
       "L 147.304048 -233.716464 \n",
       "L 140.678438 -237.23087 \n",
       "L 134.052839 -237.169612 \n",
       "L 127.427234 -233.796636 \n",
       "L 120.801634 -227.571914 \n",
       "L 114.17603 -219.765988 \n",
       "L 107.550425 -224.660237 \n",
       "L 100.924825 -231.613869 \n",
       "L 94.29922 -239.756555 \n",
       "L 87.673618 -248.651623 \n",
       "L 81.048014 -257.850106 \n",
       "L 74.422411 -266.931317 \n",
       "L 67.796808 -275.538166 \n",
       "L 61.171205 -283.40019 \n",
       "L 54.545602 -290.343375 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pc88061c8ed)\">\n",
       "     <use xlink:href=\"#m11983e82db\" x=\"0\" y=\"322.510875\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_13\">\n",
       "    <defs>\n",
       "     <path id=\"m627e338ab1\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pc88061c8ed)\">\n",
       "     <use xlink:href=\"#m627e338ab1\" x=\"356.349693\" y=\"99.955337\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m627e338ab1\" x=\"157.258364\" y=\"100.881415\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m627e338ab1\" x=\"114.255683\" y=\"103.362537\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m627e338ab1\" x=\"246.688093\" y=\"239.858537\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <path d=\"M 54.545602 106.952525 \n",
       "L 61.171205 108.332848 \n",
       "L 67.796808 109.450684 \n",
       "L 74.422411 110.188917 \n",
       "L 81.048014 110.441666 \n",
       "L 87.673618 110.129315 \n",
       "L 94.29922 109.214328 \n",
       "L 100.924825 107.715775 \n",
       "L 107.550425 105.720759 \n",
       "L 114.17603 103.390767 \n",
       "L 120.801634 100.961251 \n",
       "L 127.427234 98.733406 \n",
       "L 134.052839 97.058071 \n",
       "L 140.678438 96.312278 \n",
       "L 147.304048 96.870032 \n",
       "L 153.929648 99.06959 \n",
       "L 160.555248 103.18011 \n",
       "L 167.180857 109.370721 \n",
       "L 173.806457 117.685076 \n",
       "L 180.432057 128.02432 \n",
       "L 187.057666 140.140556 \n",
       "L 193.683266 153.642126 \n",
       "L 200.308866 168.011399 \n",
       "L 206.934475 182.633975 \n",
       "L 213.560075 196.837675 \n",
       "L 220.185675 209.938393 \n",
       "L 226.811275 221.288618 \n",
       "L 233.436875 230.324609 \n",
       "L 240.062494 236.607558 \n",
       "L 246.688093 239.8547 \n",
       "L 253.313693 239.957464 \n",
       "L 259.939293 236.984686 \n",
       "L 266.564893 231.170966 \n",
       "L 273.190493 222.891835 \n",
       "L 279.816112 212.628727 \n",
       "L 286.441712 200.927723 \n",
       "L 293.067312 188.356639 \n",
       "L 299.692911 175.464908 \n",
       "L 306.318511 162.749408 \n",
       "L 312.944111 150.629615 \n",
       "L 319.56973 139.432083 \n",
       "L 326.19533 129.385032 \n",
       "L 332.82093 120.621509 \n",
       "L 339.44653 113.189102 \n",
       "L 346.072129 107.064388 \n",
       "L 352.697729 102.169219 \n",
       "L 359.323348 98.387315 \n",
       "L 365.948948 95.579722 \n",
       "L 372.574548 93.597722 \n",
       "L 379.200148 92.293311 \n",
       "\" clip-path=\"url(#pc88061c8ed)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 54.545602 183.830923 \n",
       "L 61.171205 172.772014 \n",
       "L 67.796808 161.880495 \n",
       "L 74.422411 151.321773 \n",
       "L 81.048014 141.257109 \n",
       "L 87.673618 131.841365 \n",
       "L 94.29922 123.220756 \n",
       "L 100.924825 115.530865 \n",
       "L 107.550425 108.894678 \n",
       "L 114.17603 103.420876 \n",
       "L 120.801634 99.202298 \n",
       "L 127.427234 96.31463 \n",
       "L 134.052839 94.815243 \n",
       "L 140.678438 94.742355 \n",
       "L 147.304048 96.1143 \n",
       "L 153.929648 98.929064 \n",
       "L 160.555248 103.164005 \n",
       "L 167.180857 108.775718 \n",
       "L 173.806457 115.700081 \n",
       "L 180.432057 123.852328 \n",
       "L 187.057666 133.127327 \n",
       "L 193.683266 143.399678 \n",
       "L 200.308866 154.524081 \n",
       "L 206.934475 166.33538 \n",
       "L 213.560075 178.648512 \n",
       "L 220.185675 191.25865 \n",
       "L 226.811275 203.940835 \n",
       "L 233.436875 216.449458 \n",
       "L 240.062494 228.518084 \n",
       "L 246.688093 239.858537 \n",
       "L 253.313693 250.1611 \n",
       "L 259.939293 259.094478 \n",
       "L 266.564893 266.307334 \n",
       "L 273.190493 271.431339 \n",
       "L 279.816112 274.0875 \n",
       "L 286.441712 273.896782 \n",
       "L 293.067312 270.49767 \n",
       "L 299.692911 263.57328 \n",
       "L 306.318511 252.8915 \n",
       "L 312.944111 238.362509 \n",
       "L 319.56973 220.117276 \n",
       "L 326.19533 198.610017 \n",
       "L 332.82093 174.742393 \n",
       "L 339.44653 149.999768 \n",
       "L 346.072129 126.572344 \n",
       "L 352.697729 107.40733 \n",
       "L 359.323348 96.099121 \n",
       "L 365.948948 96.477047 \n",
       "L 372.574548 111.717136 \n",
       "L 379.200148 142.838588 \n",
       "\" clip-path=\"url(#pc88061c8ed)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <defs>\n",
       "     <path id=\"m53919e7d3f\" d=\"M 0 2.4 \n",
       "C 0.636487 2.4 1.246992 2.147121 1.697056 1.697056 \n",
       "C 2.147121 1.246992 2.4 0.636487 2.4 0 \n",
       "C 2.4 -0.636487 2.147121 -1.246992 1.697056 -1.697056 \n",
       "C 1.246992 -2.147121 0.636487 -2.4 0 -2.4 \n",
       "C -0.636487 -2.4 -1.246992 -2.147121 -1.697056 -1.697056 \n",
       "C -2.147121 -1.246992 -2.4 -0.636487 -2.4 0 \n",
       "C -2.4 0.636487 -2.147121 1.246992 -1.697056 1.697056 \n",
       "C -1.246992 2.147121 -0.636487 2.4 0 2.4 \n",
       "z\n",
       "\" style=\"stroke: #008000\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pc88061c8ed)\">\n",
       "     <use xlink:href=\"#m53919e7d3f\" x=\"246.688088\" y=\"239.858526\" style=\"fill: #008000; stroke: #008000\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 274.376352 \n",
       "L 38.312875 49.652144 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 286.1835 \n",
       "L 379.200148 286.1835 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_15\">\n",
       "    <!-- BGO iteration #1 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(181.123375 14.0715) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-42\" d=\"M 469 0 \n",
       "L 469 4581 \n",
       "L 2188 4581 \n",
       "Q 2713 4581 3030 4442 \n",
       "Q 3347 4303 3526 4014 \n",
       "Q 3706 3725 3706 3409 \n",
       "Q 3706 3116 3547 2856 \n",
       "Q 3388 2597 3066 2438 \n",
       "Q 3481 2316 3704 2022 \n",
       "Q 3928 1728 3928 1328 \n",
       "Q 3928 1006 3792 729 \n",
       "Q 3656 453 3456 303 \n",
       "Q 3256 153 2954 76 \n",
       "Q 2653 0 2216 0 \n",
       "L 469 0 \n",
       "z\n",
       "M 1075 2656 \n",
       "L 2066 2656 \n",
       "Q 2469 2656 2644 2709 \n",
       "Q 2875 2778 2992 2937 \n",
       "Q 3109 3097 3109 3338 \n",
       "Q 3109 3566 3000 3739 \n",
       "Q 2891 3913 2687 3977 \n",
       "Q 2484 4041 1991 4041 \n",
       "L 1075 4041 \n",
       "L 1075 2656 \n",
       "z\n",
       "M 1075 541 \n",
       "L 2216 541 \n",
       "Q 2509 541 2628 563 \n",
       "Q 2838 600 2978 687 \n",
       "Q 3119 775 3209 942 \n",
       "Q 3300 1109 3300 1328 \n",
       "Q 3300 1584 3169 1773 \n",
       "Q 3038 1963 2805 2039 \n",
       "Q 2572 2116 2134 2116 \n",
       "L 1075 2116 \n",
       "L 1075 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-47\" d=\"M 2638 1797 \n",
       "L 2638 2334 \n",
       "L 4578 2338 \n",
       "L 4578 638 \n",
       "Q 4131 281 3656 101 \n",
       "Q 3181 -78 2681 -78 \n",
       "Q 2006 -78 1454 211 \n",
       "Q 903 500 622 1047 \n",
       "Q 341 1594 341 2269 \n",
       "Q 341 2938 620 3517 \n",
       "Q 900 4097 1425 4378 \n",
       "Q 1950 4659 2634 4659 \n",
       "Q 3131 4659 3532 4498 \n",
       "Q 3934 4338 4162 4050 \n",
       "Q 4391 3763 4509 3300 \n",
       "L 3963 3150 \n",
       "Q 3859 3500 3706 3700 \n",
       "Q 3553 3900 3268 4020 \n",
       "Q 2984 4141 2638 4141 \n",
       "Q 2222 4141 1919 4014 \n",
       "Q 1616 3888 1430 3681 \n",
       "Q 1244 3475 1141 3228 \n",
       "Q 966 2803 966 2306 \n",
       "Q 966 1694 1177 1281 \n",
       "Q 1388 869 1791 669 \n",
       "Q 2194 469 2647 469 \n",
       "Q 3041 469 3416 620 \n",
       "Q 3791 772 3984 944 \n",
       "L 3984 1797 \n",
       "L 2638 1797 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-23\" d=\"M 322 -78 \n",
       "L 594 1253 \n",
       "L 66 1253 \n",
       "L 66 1719 \n",
       "L 688 1719 \n",
       "L 919 2853 \n",
       "L 66 2853 \n",
       "L 66 3319 \n",
       "L 1013 3319 \n",
       "L 1284 4659 \n",
       "L 1753 4659 \n",
       "L 1481 3319 \n",
       "L 2466 3319 \n",
       "L 2738 4659 \n",
       "L 3209 4659 \n",
       "L 2938 3319 \n",
       "L 3478 3319 \n",
       "L 3478 2853 \n",
       "L 2844 2853 \n",
       "L 2609 1719 \n",
       "L 3478 1719 \n",
       "L 3478 1253 \n",
       "L 2516 1253 \n",
       "L 2244 -78 \n",
       "L 1775 -78 \n",
       "L 2044 1253 \n",
       "L 1063 1253 \n",
       "L 791 -78 \n",
       "L 322 -78 \n",
       "z\n",
       "M 1156 1719 \n",
       "L 2138 1719 \n",
       "L 2372 2853 \n",
       "L 1388 2853 \n",
       "L 1156 1719 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-42\"/>\n",
       "     <use xlink:href=\"#ArialMT-47\" x=\"66.699219\"/>\n",
       "     <use xlink:href=\"#ArialMT-4f\" x=\"144.482422\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"222.265625\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"250.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"272.265625\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"300.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"355.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"388.964844\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"444.580078\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"472.363281\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"494.580078\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"550.195312\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"605.810547\"/>\n",
       "     <use xlink:href=\"#ArialMT-23\" x=\"633.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"689.208984\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_17\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m627e338ab1\" x=\"55.032875\" y=\"207.53075\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 210.61075) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 46.232875 220.11475 \n",
       "L 55.032875 220.11475 \n",
       "L 63.832875 220.11475 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 223.19475) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 46.232875 237.35175 \n",
       "L 63.832875 237.35175 \n",
       "L 63.832875 231.19175 \n",
       "L 46.232875 231.19175 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 237.35175) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 46.232875 251.51975 \n",
       "L 63.832875 251.51975 \n",
       "L 63.832875 245.35975 \n",
       "L 46.232875 245.35975 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 251.51975) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_19\">\n",
       "     <path d=\"M 46.232875 260.986625 \n",
       "L 55.032875 260.986625 \n",
       "L 63.832875 260.986625 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 264.066625) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_20\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m53919e7d3f\" x=\"55.032875\" y=\"273.4345\" style=\"fill: #008000; stroke: #008000\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- Next observation -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 276.5145) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4e\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"72.216797\"/>\n",
       "      <use xlink:href=\"#ArialMT-78\" x=\"127.832031\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"177.832031\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"205.615234\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"233.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"289.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"344.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"394.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"450.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"533.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"589.160156\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"616.943359\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"639.160156\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"694.775391\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pc88061c8ed\">\n",
       "   <rect x=\"38.312875\" y=\"20.0715\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"402.632875pt\" height=\"322.510875pt\" viewBox=\"0 0 402.632875 322.510875\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:17:14.681554</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.510875 \n",
       "L 402.632875 322.510875 \n",
       "L 402.632875 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 286.1835 \n",
       "L 395.432875 286.1835 \n",
       "L 395.432875 20.0715 \n",
       "L 38.312875 20.0715 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"ma368927e3b\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma368927e3b\" x=\"54.545602\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma368927e3b\" x=\"119.476511\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma368927e3b\" x=\"184.40742\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma368927e3b\" x=\"249.33833\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma368927e3b\" x=\"314.269239\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma368927e3b\" x=\"379.200148\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 313.402875) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"mb362e62bb3\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb362e62bb3\" x=\"38.312875\" y=\"274.377162\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 277.526599) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb362e62bb3\" x=\"38.312875\" y=\"229.306332\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 232.45577) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb362e62bb3\" x=\"38.312875\" y=\"184.235503\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 187.384941) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb362e62bb3\" x=\"38.312875\" y=\"139.164674\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 142.314112) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb362e62bb3\" x=\"38.312875\" y=\"94.093845\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 97.243282) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb362e62bb3\" x=\"38.312875\" y=\"49.023016\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 52.172453) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_14\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.0075) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m18667cae5e\" d=\"M 54.545602 -290.342026 \n",
       "L 54.545602 -140.359177 \n",
       "L 61.171205 -144.49858 \n",
       "L 67.796808 -150.108852 \n",
       "L 74.422411 -157.25781 \n",
       "L 81.048014 -165.892917 \n",
       "L 87.673618 -175.819746 \n",
       "L 94.29922 -186.692623 \n",
       "L 100.924825 -198.019891 \n",
       "L 107.550425 -209.18365 \n",
       "L 114.17603 -219.130551 \n",
       "L 120.801634 -216.205432 \n",
       "L 127.427234 -214.590753 \n",
       "L 134.052839 -214.676117 \n",
       "L 140.678438 -216.134217 \n",
       "L 147.304048 -218.45262 \n",
       "L 153.929648 -220.964114 \n",
       "L 160.555248 -216.176554 \n",
       "L 167.180857 -201.992169 \n",
       "L 173.806457 -185.202643 \n",
       "L 180.432057 -166.618463 \n",
       "L 187.057666 -147.172433 \n",
       "L 193.683266 -127.876779 \n",
       "L 200.308866 -109.766743 \n",
       "L 206.934475 -93.842108 \n",
       "L 213.560075 -81.01078 \n",
       "L 220.185675 -72.037069 \n",
       "L 226.811275 -67.496808 \n",
       "L 233.436875 -67.741649 \n",
       "L 240.062494 -72.873043 \n",
       "L 246.688093 -82.301663 \n",
       "L 253.313693 -75.519511 \n",
       "L 259.939293 -72.572324 \n",
       "L 266.564893 -74.13601 \n",
       "L 273.190493 -80.177116 \n",
       "L 279.816112 -90.382468 \n",
       "L 286.441712 -104.17887 \n",
       "L 293.067312 -120.767086 \n",
       "L 299.692911 -139.168981 \n",
       "L 306.318511 -158.284843 \n",
       "L 312.944111 -176.960114 \n",
       "L 319.56973 -194.056936 \n",
       "L 326.19533 -208.528285 \n",
       "L 332.82093 -219.489935 \n",
       "L 339.44653 -226.286184 \n",
       "L 346.072129 -228.539511 \n",
       "L 352.697729 -226.166865 \n",
       "L 359.323348 -216.419801 \n",
       "L 365.948948 -202.343995 \n",
       "L 372.574548 -189.873457 \n",
       "L 379.200148 -179.595519 \n",
       "L 379.200148 -180.497547 \n",
       "L 379.200148 -180.497547 \n",
       "L 372.574548 -195.565977 \n",
       "L 365.948948 -209.047648 \n",
       "L 359.323348 -219.575981 \n",
       "L 352.697729 -231.122943 \n",
       "L 346.072129 -244.930519 \n",
       "L 339.44653 -256.764645 \n",
       "L 332.82093 -265.495384 \n",
       "L 326.19533 -270.223827 \n",
       "L 319.56973 -270.337665 \n",
       "L 312.944111 -265.553919 \n",
       "L 306.318511 -255.932969 \n",
       "L 299.692911 -241.864696 \n",
       "L 293.067312 -224.030631 \n",
       "L 286.441712 -203.347774 \n",
       "L 279.816112 -180.901087 \n",
       "L 273.190493 -157.869918 \n",
       "L 266.564893 -135.453771 \n",
       "L 259.939293 -114.802049 \n",
       "L 253.313693 -96.952006 \n",
       "L 246.688093 -83.203229 \n",
       "L 240.062494 -93.75323 \n",
       "L 233.436875 -107.780041 \n",
       "L 226.811275 -123.951463 \n",
       "L 220.185675 -141.262328 \n",
       "L 213.560075 -158.681038 \n",
       "L 206.934475 -175.227227 \n",
       "L 200.308866 -190.046307 \n",
       "L 193.683266 -202.47423 \n",
       "L 187.057666 -212.085511 \n",
       "L 180.432057 -218.71991 \n",
       "L 173.806457 -222.484483 \n",
       "L 167.180857 -223.732611 \n",
       "L 160.555248 -223.029465 \n",
       "L 153.929648 -227.238579 \n",
       "L 147.304048 -234.612109 \n",
       "L 140.678438 -238.229122 \n",
       "L 134.052839 -238.146807 \n",
       "L 127.427234 -234.657235 \n",
       "L 120.801634 -228.246305 \n",
       "L 114.17603 -220.061977 \n",
       "L 107.550425 -224.939207 \n",
       "L 100.924825 -231.73435 \n",
       "L 94.29922 -239.746578 \n",
       "L 87.673618 -248.550381 \n",
       "L 81.048014 -257.699754 \n",
       "L 74.422411 -266.772382 \n",
       "L 67.796808 -275.406078 \n",
       "L 61.171205 -283.323307 \n",
       "L 54.545602 -290.342026 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p0f66f179f7)\">\n",
       "     <use xlink:href=\"#m18667cae5e\" x=\"0\" y=\"322.510875\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m14d65910e7\" d=\"M 54.545602 -140.359177 \n",
       "L 54.545602 -140.357828 \n",
       "L 61.171205 -144.497119 \n",
       "L 67.796808 -150.10723 \n",
       "L 74.422411 -157.255951 \n",
       "L 81.048014 -165.890703 \n",
       "L 87.673618 -175.816952 \n",
       "L 94.29922 -186.688792 \n",
       "L 100.924825 -198.013866 \n",
       "L 107.550425 -209.170766 \n",
       "L 114.17603 -218.948169 \n",
       "L 120.801634 -216.188585 \n",
       "L 127.427234 -214.580634 \n",
       "L 134.052839 -214.667464 \n",
       "L 140.678438 -216.125027 \n",
       "L 147.304048 -218.440058 \n",
       "L 153.929648 -220.931903 \n",
       "L 160.555248 -216.147038 \n",
       "L 167.180857 -201.982828 \n",
       "L 173.806457 -185.197195 \n",
       "L 180.432057 -166.614568 \n",
       "L 187.057666 -147.1693 \n",
       "L 193.683266 -127.87406 \n",
       "L 200.308866 -109.764218 \n",
       "L 206.934475 -93.839615 \n",
       "L 213.560075 -81.008158 \n",
       "L 220.185675 -72.034136 \n",
       "L 226.811275 -67.493208 \n",
       "L 233.436875 -67.736577 \n",
       "L 240.062494 -72.863319 \n",
       "L 246.688093 -82.114999 \n",
       "L 253.313693 -75.510033 \n",
       "L 259.939293 -72.56751 \n",
       "L 266.564893 -74.132689 \n",
       "L 273.190493 -80.174494 \n",
       "L 279.816112 -90.380223 \n",
       "L 286.441712 -104.176828 \n",
       "L 293.067312 -120.76513 \n",
       "L 299.692911 -139.166998 \n",
       "L 306.318511 -158.282764 \n",
       "L 312.944111 -176.95782 \n",
       "L 319.56973 -194.054274 \n",
       "L 326.19533 -208.524994 \n",
       "L 332.82093 -219.485518 \n",
       "L 339.44653 -226.279521 \n",
       "L 346.072129 -228.527128 \n",
       "L 352.697729 -226.126211 \n",
       "L 359.323348 -216.356701 \n",
       "L 365.948948 -202.313829 \n",
       "L 372.574548 -189.837993 \n",
       "L 379.200148 -179.40892 \n",
       "L 379.200148 -179.595519 \n",
       "L 379.200148 -179.595519 \n",
       "L 372.574548 -189.873457 \n",
       "L 365.948948 -202.343995 \n",
       "L 359.323348 -216.419801 \n",
       "L 352.697729 -226.166865 \n",
       "L 346.072129 -228.539511 \n",
       "L 339.44653 -226.286184 \n",
       "L 332.82093 -219.489935 \n",
       "L 326.19533 -208.528285 \n",
       "L 319.56973 -194.056936 \n",
       "L 312.944111 -176.960114 \n",
       "L 306.318511 -158.284843 \n",
       "L 299.692911 -139.168981 \n",
       "L 293.067312 -120.767086 \n",
       "L 286.441712 -104.17887 \n",
       "L 279.816112 -90.382468 \n",
       "L 273.190493 -80.177116 \n",
       "L 266.564893 -74.13601 \n",
       "L 259.939293 -72.572324 \n",
       "L 253.313693 -75.519511 \n",
       "L 246.688093 -82.301663 \n",
       "L 240.062494 -72.873043 \n",
       "L 233.436875 -67.741649 \n",
       "L 226.811275 -67.496808 \n",
       "L 220.185675 -72.037069 \n",
       "L 213.560075 -81.01078 \n",
       "L 206.934475 -93.842108 \n",
       "L 200.308866 -109.766743 \n",
       "L 193.683266 -127.876779 \n",
       "L 187.057666 -147.172433 \n",
       "L 180.432057 -166.618463 \n",
       "L 173.806457 -185.202643 \n",
       "L 167.180857 -201.992169 \n",
       "L 160.555248 -216.176554 \n",
       "L 153.929648 -220.964114 \n",
       "L 147.304048 -218.45262 \n",
       "L 140.678438 -216.134217 \n",
       "L 134.052839 -214.676117 \n",
       "L 127.427234 -214.590753 \n",
       "L 120.801634 -216.205432 \n",
       "L 114.17603 -219.130551 \n",
       "L 107.550425 -209.18365 \n",
       "L 100.924825 -198.019891 \n",
       "L 94.29922 -186.692623 \n",
       "L 87.673618 -175.819746 \n",
       "L 81.048014 -165.892917 \n",
       "L 74.422411 -157.25781 \n",
       "L 67.796808 -150.108852 \n",
       "L 61.171205 -144.49858 \n",
       "L 54.545602 -140.359177 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p0f66f179f7)\">\n",
       "     <use xlink:href=\"#m14d65910e7\" x=\"0\" y=\"322.510875\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m5a13fb0fe6\" d=\"M 54.545602 -290.343375 \n",
       "L 54.545602 -290.342026 \n",
       "L 61.171205 -283.323307 \n",
       "L 67.796808 -275.406078 \n",
       "L 74.422411 -266.772382 \n",
       "L 81.048014 -257.699754 \n",
       "L 87.673618 -248.550381 \n",
       "L 94.29922 -239.746578 \n",
       "L 100.924825 -231.73435 \n",
       "L 107.550425 -224.939207 \n",
       "L 114.17603 -220.061977 \n",
       "L 120.801634 -228.246305 \n",
       "L 127.427234 -234.657235 \n",
       "L 134.052839 -238.146807 \n",
       "L 140.678438 -238.229122 \n",
       "L 147.304048 -234.612109 \n",
       "L 153.929648 -227.238579 \n",
       "L 160.555248 -223.029465 \n",
       "L 167.180857 -223.732611 \n",
       "L 173.806457 -222.484483 \n",
       "L 180.432057 -218.71991 \n",
       "L 187.057666 -212.085511 \n",
       "L 193.683266 -202.47423 \n",
       "L 200.308866 -190.046307 \n",
       "L 206.934475 -175.227227 \n",
       "L 213.560075 -158.681038 \n",
       "L 220.185675 -141.262328 \n",
       "L 226.811275 -123.951463 \n",
       "L 233.436875 -107.780041 \n",
       "L 240.062494 -93.75323 \n",
       "L 246.688093 -83.203229 \n",
       "L 253.313693 -96.952006 \n",
       "L 259.939293 -114.802049 \n",
       "L 266.564893 -135.453771 \n",
       "L 273.190493 -157.869918 \n",
       "L 279.816112 -180.901087 \n",
       "L 286.441712 -203.347774 \n",
       "L 293.067312 -224.030631 \n",
       "L 299.692911 -241.864696 \n",
       "L 306.318511 -255.932969 \n",
       "L 312.944111 -265.553919 \n",
       "L 319.56973 -270.337665 \n",
       "L 326.19533 -270.223827 \n",
       "L 332.82093 -265.495384 \n",
       "L 339.44653 -256.764645 \n",
       "L 346.072129 -244.930519 \n",
       "L 352.697729 -231.122943 \n",
       "L 359.323348 -219.575981 \n",
       "L 365.948948 -209.047648 \n",
       "L 372.574548 -195.565977 \n",
       "L 379.200148 -180.497547 \n",
       "L 379.200148 -180.684147 \n",
       "L 379.200148 -180.684147 \n",
       "L 372.574548 -195.60144 \n",
       "L 365.948948 -209.077815 \n",
       "L 359.323348 -219.639081 \n",
       "L 352.697729 -231.163597 \n",
       "L 346.072129 -244.942902 \n",
       "L 339.44653 -256.77131 \n",
       "L 332.82093 -265.499801 \n",
       "L 326.19533 -270.227118 \n",
       "L 319.56973 -270.340327 \n",
       "L 312.944111 -265.55621 \n",
       "L 306.318511 -255.935049 \n",
       "L 299.692911 -241.866678 \n",
       "L 293.067312 -224.032598 \n",
       "L 286.441712 -203.349821 \n",
       "L 279.816112 -180.903327 \n",
       "L 273.190493 -157.872535 \n",
       "L 266.564893 -135.457091 \n",
       "L 259.939293 -114.806863 \n",
       "L 253.313693 -96.961484 \n",
       "L 246.688093 -83.389893 \n",
       "L 240.062494 -93.762955 \n",
       "L 233.436875 -107.785113 \n",
       "L 226.811275 -123.955062 \n",
       "L 220.185675 -141.265262 \n",
       "L 213.560075 -158.68366 \n",
       "L 206.934475 -175.22972 \n",
       "L 200.308866 -190.04884 \n",
       "L 193.683266 -202.476954 \n",
       "L 187.057666 -212.088641 \n",
       "L 180.432057 -218.723808 \n",
       "L 173.806457 -222.489931 \n",
       "L 167.180857 -223.741951 \n",
       "L 160.555248 -223.05898 \n",
       "L 153.929648 -227.270789 \n",
       "L 147.304048 -234.624671 \n",
       "L 140.678438 -238.238312 \n",
       "L 134.052839 -238.15546 \n",
       "L 127.427234 -234.667354 \n",
       "L 120.801634 -228.263152 \n",
       "L 114.17603 -220.244358 \n",
       "L 107.550425 -224.95209 \n",
       "L 100.924825 -231.740375 \n",
       "L 94.29922 -239.750406 \n",
       "L 87.673618 -248.553172 \n",
       "L 81.048014 -257.701968 \n",
       "L 74.422411 -266.774235 \n",
       "L 67.796808 -275.407701 \n",
       "L 61.171205 -283.324768 \n",
       "L 54.545602 -290.343375 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p0f66f179f7)\">\n",
       "     <use xlink:href=\"#m5a13fb0fe6\" x=\"0\" y=\"322.510875\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_13\">\n",
       "    <defs>\n",
       "     <path id=\"mb889675cb1\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p0f66f179f7)\">\n",
       "     <use xlink:href=\"#mb889675cb1\" x=\"356.349693\" y=\"99.467217\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb889675cb1\" x=\"157.258364\" y=\"100.39589\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb889675cb1\" x=\"114.255683\" y=\"102.883967\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb889675cb1\" x=\"246.688093\" y=\"239.762587\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mb889675cb1\" x=\"379.200148\" y=\"142.470676\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <path d=\"M 54.545602 107.160273 \n",
       "L 61.171205 108.599933 \n",
       "L 67.796808 109.753411 \n",
       "L 74.422411 110.495781 \n",
       "L 81.048014 110.714541 \n",
       "L 87.673618 110.325813 \n",
       "L 94.29922 109.291275 \n",
       "L 100.924825 107.633754 \n",
       "L 107.550425 105.449447 \n",
       "L 114.17603 102.914611 \n",
       "L 120.801634 100.285007 \n",
       "L 127.427234 97.886881 \n",
       "L 134.052839 96.099413 \n",
       "L 140.678438 95.329205 \n",
       "L 147.304048 95.97851 \n",
       "L 153.929648 98.409529 \n",
       "L 160.555248 102.907866 \n",
       "L 167.180857 109.648486 \n",
       "L 173.806457 118.667312 \n",
       "L 180.432057 129.841687 \n",
       "L 187.057666 142.881904 \n",
       "L 193.683266 157.335369 \n",
       "L 200.308866 172.604349 \n",
       "L 206.934475 187.976208 \n",
       "L 213.560075 202.664966 \n",
       "L 220.185675 215.861176 \n",
       "L 226.811275 226.78674 \n",
       "L 233.436875 234.75003 \n",
       "L 240.062494 239.197738 \n",
       "L 246.688093 239.758429 \n",
       "L 253.313693 236.275117 \n",
       "L 259.939293 228.823688 \n",
       "L 266.564893 217.715985 \n",
       "L 273.190493 203.487358 \n",
       "L 279.816112 186.869097 \n",
       "L 286.441712 168.747553 \n",
       "L 293.067312 150.112014 \n",
       "L 299.692911 131.994037 \n",
       "L 306.318511 115.401969 \n",
       "L 312.944111 101.25386 \n",
       "L 319.56973 90.313575 \n",
       "L 326.19533 83.134819 \n",
       "L 332.82093 80.018216 \n",
       "L 339.44653 80.98546 \n",
       "L 346.072129 85.77586 \n",
       "L 352.697729 93.865971 \n",
       "L 359.323348 104.512984 \n",
       "L 365.948948 116.815053 \n",
       "L 372.574548 129.791158 \n",
       "L 379.200148 142.464342 \n",
       "\" clip-path=\"url(#p0f66f179f7)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 54.545602 183.577919 \n",
       "L 61.171205 172.48801 \n",
       "L 67.796808 161.565961 \n",
       "L 74.422411 150.977641 \n",
       "L 81.048014 140.884763 \n",
       "L 87.673618 131.442625 \n",
       "L 94.29922 122.797852 \n",
       "L 100.924825 115.086405 \n",
       "L 107.550425 108.431616 \n",
       "L 114.17603 102.94247 \n",
       "L 120.801634 98.712066 \n",
       "L 127.427234 95.816304 \n",
       "L 134.052839 94.312714 \n",
       "L 140.678438 94.239621 \n",
       "L 147.304048 95.615412 \n",
       "L 153.929648 98.438067 \n",
       "L 160.555248 102.684878 \n",
       "L 167.180857 108.312322 \n",
       "L 173.806457 115.256096 \n",
       "L 180.432057 123.431195 \n",
       "L 187.057666 132.732193 \n",
       "L 193.683266 143.033338 \n",
       "L 200.308866 154.188925 \n",
       "L 206.934475 166.033334 \n",
       "L 213.560075 178.380981 \n",
       "L 220.185675 191.026467 \n",
       "L 226.811275 203.744202 \n",
       "L 233.436875 216.287889 \n",
       "L 240.062494 228.390346 \n",
       "L 246.688093 239.762587 \n",
       "L 253.313693 250.09403 \n",
       "L 259.939293 259.05245 \n",
       "L 266.564893 266.285525 \n",
       "L 273.190493 271.423893 \n",
       "L 279.816112 274.0875 \n",
       "L 286.441712 273.896248 \n",
       "L 293.067312 270.487608 \n",
       "L 299.692911 263.543807 \n",
       "L 306.318511 252.832084 \n",
       "L 312.944111 238.262366 \n",
       "L 319.56973 219.965989 \n",
       "L 326.19533 198.398441 \n",
       "L 332.82093 174.463912 \n",
       "L 339.44653 149.65193 \n",
       "L 346.072129 126.158835 \n",
       "L 352.697729 106.940099 \n",
       "L 359.323348 95.600191 \n",
       "L 365.948948 95.979177 \n",
       "L 372.574548 111.261986 \n",
       "L 379.200148 142.470676 \n",
       "\" clip-path=\"url(#p0f66f179f7)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <defs>\n",
       "     <path id=\"m912479a72a\" d=\"M 0 2.4 \n",
       "C 0.636487 2.4 1.246992 2.147121 1.697056 1.697056 \n",
       "C 2.147121 1.246992 2.4 0.636487 2.4 0 \n",
       "C 2.4 -0.636487 2.147121 -1.246992 1.697056 -1.697056 \n",
       "C 1.246992 -2.147121 0.636487 -2.4 0 -2.4 \n",
       "C -0.636487 -2.4 -1.246992 -2.147121 -1.697056 -1.697056 \n",
       "C -2.147121 -1.246992 -2.4 -0.636487 -2.4 0 \n",
       "C -2.4 0.636487 -2.147121 1.246992 -1.697056 1.697056 \n",
       "C -1.246992 2.147121 -0.636487 2.4 0 2.4 \n",
       "z\n",
       "\" style=\"stroke: #008000\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p0f66f179f7)\">\n",
       "     <use xlink:href=\"#m912479a72a\" x=\"379.200148\" y=\"142.470709\" style=\"fill: #008000; stroke: #008000\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 274.377162 \n",
       "L 38.312875 49.023016 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 286.1835 \n",
       "L 379.200148 286.1835 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_15\">\n",
       "    <!-- BGO iteration #2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(181.123375 14.0715) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-42\" d=\"M 469 0 \n",
       "L 469 4581 \n",
       "L 2188 4581 \n",
       "Q 2713 4581 3030 4442 \n",
       "Q 3347 4303 3526 4014 \n",
       "Q 3706 3725 3706 3409 \n",
       "Q 3706 3116 3547 2856 \n",
       "Q 3388 2597 3066 2438 \n",
       "Q 3481 2316 3704 2022 \n",
       "Q 3928 1728 3928 1328 \n",
       "Q 3928 1006 3792 729 \n",
       "Q 3656 453 3456 303 \n",
       "Q 3256 153 2954 76 \n",
       "Q 2653 0 2216 0 \n",
       "L 469 0 \n",
       "z\n",
       "M 1075 2656 \n",
       "L 2066 2656 \n",
       "Q 2469 2656 2644 2709 \n",
       "Q 2875 2778 2992 2937 \n",
       "Q 3109 3097 3109 3338 \n",
       "Q 3109 3566 3000 3739 \n",
       "Q 2891 3913 2687 3977 \n",
       "Q 2484 4041 1991 4041 \n",
       "L 1075 4041 \n",
       "L 1075 2656 \n",
       "z\n",
       "M 1075 541 \n",
       "L 2216 541 \n",
       "Q 2509 541 2628 563 \n",
       "Q 2838 600 2978 687 \n",
       "Q 3119 775 3209 942 \n",
       "Q 3300 1109 3300 1328 \n",
       "Q 3300 1584 3169 1773 \n",
       "Q 3038 1963 2805 2039 \n",
       "Q 2572 2116 2134 2116 \n",
       "L 1075 2116 \n",
       "L 1075 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-47\" d=\"M 2638 1797 \n",
       "L 2638 2334 \n",
       "L 4578 2338 \n",
       "L 4578 638 \n",
       "Q 4131 281 3656 101 \n",
       "Q 3181 -78 2681 -78 \n",
       "Q 2006 -78 1454 211 \n",
       "Q 903 500 622 1047 \n",
       "Q 341 1594 341 2269 \n",
       "Q 341 2938 620 3517 \n",
       "Q 900 4097 1425 4378 \n",
       "Q 1950 4659 2634 4659 \n",
       "Q 3131 4659 3532 4498 \n",
       "Q 3934 4338 4162 4050 \n",
       "Q 4391 3763 4509 3300 \n",
       "L 3963 3150 \n",
       "Q 3859 3500 3706 3700 \n",
       "Q 3553 3900 3268 4020 \n",
       "Q 2984 4141 2638 4141 \n",
       "Q 2222 4141 1919 4014 \n",
       "Q 1616 3888 1430 3681 \n",
       "Q 1244 3475 1141 3228 \n",
       "Q 966 2803 966 2306 \n",
       "Q 966 1694 1177 1281 \n",
       "Q 1388 869 1791 669 \n",
       "Q 2194 469 2647 469 \n",
       "Q 3041 469 3416 620 \n",
       "Q 3791 772 3984 944 \n",
       "L 3984 1797 \n",
       "L 2638 1797 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-23\" d=\"M 322 -78 \n",
       "L 594 1253 \n",
       "L 66 1253 \n",
       "L 66 1719 \n",
       "L 688 1719 \n",
       "L 919 2853 \n",
       "L 66 2853 \n",
       "L 66 3319 \n",
       "L 1013 3319 \n",
       "L 1284 4659 \n",
       "L 1753 4659 \n",
       "L 1481 3319 \n",
       "L 2466 3319 \n",
       "L 2738 4659 \n",
       "L 3209 4659 \n",
       "L 2938 3319 \n",
       "L 3478 3319 \n",
       "L 3478 2853 \n",
       "L 2844 2853 \n",
       "L 2609 1719 \n",
       "L 3478 1719 \n",
       "L 3478 1253 \n",
       "L 2516 1253 \n",
       "L 2244 -78 \n",
       "L 1775 -78 \n",
       "L 2044 1253 \n",
       "L 1063 1253 \n",
       "L 791 -78 \n",
       "L 322 -78 \n",
       "z\n",
       "M 1156 1719 \n",
       "L 2138 1719 \n",
       "L 2372 2853 \n",
       "L 1388 2853 \n",
       "L 1156 1719 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-42\"/>\n",
       "     <use xlink:href=\"#ArialMT-47\" x=\"66.699219\"/>\n",
       "     <use xlink:href=\"#ArialMT-4f\" x=\"144.482422\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"222.265625\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"250.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"272.265625\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"300.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"355.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"388.964844\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"444.580078\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"472.363281\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"494.580078\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"550.195312\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"605.810547\"/>\n",
       "     <use xlink:href=\"#ArialMT-23\" x=\"633.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"689.208984\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_17\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#mb889675cb1\" x=\"55.032875\" y=\"207.53075\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 210.61075) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 46.232875 220.11475 \n",
       "L 55.032875 220.11475 \n",
       "L 63.832875 220.11475 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 223.19475) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 46.232875 237.35175 \n",
       "L 63.832875 237.35175 \n",
       "L 63.832875 231.19175 \n",
       "L 46.232875 231.19175 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 237.35175) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 46.232875 251.51975 \n",
       "L 63.832875 251.51975 \n",
       "L 63.832875 245.35975 \n",
       "L 46.232875 245.35975 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 251.51975) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_19\">\n",
       "     <path d=\"M 46.232875 260.986625 \n",
       "L 55.032875 260.986625 \n",
       "L 63.832875 260.986625 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 264.066625) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_20\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m912479a72a\" x=\"55.032875\" y=\"273.4345\" style=\"fill: #008000; stroke: #008000\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- Next observation -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 276.5145) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4e\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"72.216797\"/>\n",
       "      <use xlink:href=\"#ArialMT-78\" x=\"127.832031\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"177.832031\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"205.615234\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"233.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"289.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"344.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"394.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"450.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"533.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"589.160156\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"616.943359\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"639.160156\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"694.775391\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p0f66f179f7\">\n",
       "   <rect x=\"38.312875\" y=\"20.0715\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"407.5265pt\" height=\"322.510875pt\" viewBox=\"0 0 407.5265 322.510875\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:17:14.737615</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.510875 \n",
       "L 407.5265 322.510875 \n",
       "L 407.5265 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 43.2065 286.1835 \n",
       "L 400.3265 286.1835 \n",
       "L 400.3265 20.0715 \n",
       "L 43.2065 20.0715 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m5f6114c01a\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5f6114c01a\" x=\"59.439227\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(53.323227 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5f6114c01a\" x=\"124.370136\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(118.254136 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5f6114c01a\" x=\"189.301045\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(183.185045 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5f6114c01a\" x=\"254.231955\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(248.115955 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5f6114c01a\" x=\"319.162864\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(313.046864 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5f6114c01a\" x=\"384.093773\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.977773 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(218.8865 313.402875) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"mcdf4bbd261\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcdf4bbd261\" x=\"43.2065\" y=\"271.229261\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −12 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 274.378698) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcdf4bbd261\" x=\"43.2065\" y=\"239.56137\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 242.710807) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcdf4bbd261\" x=\"43.2065\" y=\"207.893479\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 211.042916) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcdf4bbd261\" x=\"43.2065\" y=\"176.225587\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 179.375025) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcdf4bbd261\" x=\"43.2065\" y=\"144.557696\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 147.707134) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcdf4bbd261\" x=\"43.2065\" y=\"112.889805\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 116.039242) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcdf4bbd261\" x=\"43.2065\" y=\"81.221914\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(30.012875 84.371351) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcdf4bbd261\" x=\"43.2065\" y=\"49.554022\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(30.012875 52.70346) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.0075) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"mf295aca3ec\" d=\"M 59.439227 -290.342424 \n",
       "L 59.439227 -184.995561 \n",
       "L 66.06483 -188.362281 \n",
       "L 72.690433 -192.572963 \n",
       "L 79.316036 -197.613278 \n",
       "L 85.941639 -203.394099 \n",
       "L 92.567243 -209.745354 \n",
       "L 99.192845 -216.418758 \n",
       "L 105.81845 -223.099968 \n",
       "L 112.44405 -229.428407 \n",
       "L 119.069655 -234.783361 \n",
       "L 125.695259 -231.172462 \n",
       "L 132.320859 -228.72926 \n",
       "L 138.946464 -227.945155 \n",
       "L 145.572063 -228.812631 \n",
       "L 152.197673 -231.175736 \n",
       "L 158.823273 -234.726334 \n",
       "L 165.448873 -234.358873 \n",
       "L 172.074482 -228.658822 \n",
       "L 178.700082 -222.245133 \n",
       "L 185.325682 -215.449186 \n",
       "L 191.951291 -208.542854 \n",
       "L 198.576891 -201.710507 \n",
       "L 205.202491 -195.024635 \n",
       "L 211.8281 -188.436179 \n",
       "L 218.4537 -181.783085 \n",
       "L 225.0793 -174.818323 \n",
       "L 231.7049 -167.256806 \n",
       "L 238.3305 -158.837397 \n",
       "L 244.956119 -149.392669 \n",
       "L 251.581718 -138.62167 \n",
       "L 258.207318 -116.019063 \n",
       "L 264.832918 -94.353031 \n",
       "L 271.458518 -75.387045 \n",
       "L 278.084118 -60.581982 \n",
       "L 284.709737 -51.254932 \n",
       "L 291.335337 -48.426153 \n",
       "L 297.960937 -52.671306 \n",
       "L 304.586536 -63.999707 \n",
       "L 311.212136 -81.782876 \n",
       "L 317.837736 -104.755066 \n",
       "L 324.463355 -131.090339 \n",
       "L 331.088955 -158.556907 \n",
       "L 337.714555 -184.527652 \n",
       "L 344.340155 -205.823694 \n",
       "L 350.965754 -222.878892 \n",
       "L 357.591354 -234.101047 \n",
       "L 364.216973 -237.683332 \n",
       "L 370.842573 -233.340313 \n",
       "L 377.468173 -222.648958 \n",
       "L 384.093773 -207.004985 \n",
       "L 384.093773 -207.638773 \n",
       "L 384.093773 -207.638773 \n",
       "L 377.468173 -224.442115 \n",
       "L 370.842573 -235.153623 \n",
       "L 364.216973 -238.579109 \n",
       "L 357.591354 -235.084367 \n",
       "L 350.965754 -224.717864 \n",
       "L 344.340155 -207.551387 \n",
       "L 337.714555 -185.160685 \n",
       "L 331.088955 -162.048639 \n",
       "L 324.463355 -139.515759 \n",
       "L 317.837736 -119.307763 \n",
       "L 311.212136 -102.980071 \n",
       "L 304.586536 -91.549591 \n",
       "L 297.960937 -85.433495 \n",
       "L 291.335337 -84.483014 \n",
       "L 284.709737 -88.079951 \n",
       "L 278.084118 -95.2837 \n",
       "L 271.458518 -104.996476 \n",
       "L 264.832918 -116.120357 \n",
       "L 258.207318 -127.689308 \n",
       "L 251.581718 -139.255646 \n",
       "L 244.956119 -161.748669 \n",
       "L 238.3305 -183.277118 \n",
       "L 231.7049 -202.619749 \n",
       "L 225.0793 -219.115116 \n",
       "L 218.4537 -232.361294 \n",
       "L 211.8281 -242.197626 \n",
       "L 205.202491 -248.678399 \n",
       "L 198.576891 -252.042232 \n",
       "L 191.951291 -252.679125 \n",
       "L 185.325682 -251.096208 \n",
       "L 178.700082 -247.882075 \n",
       "L 172.074482 -243.670101 \n",
       "L 165.448873 -239.107413 \n",
       "L 158.823273 -239.085616 \n",
       "L 152.197673 -242.424633 \n",
       "L 145.572063 -244.22008 \n",
       "L 138.946464 -244.335373 \n",
       "L 132.320859 -242.758482 \n",
       "L 125.695259 -239.598784 \n",
       "L 119.069655 -235.437313 \n",
       "L 112.44405 -240.469777 \n",
       "L 105.81845 -246.738928 \n",
       "L 99.192845 -253.63367 \n",
       "L 92.567243 -260.780446 \n",
       "L 85.941639 -267.833527 \n",
       "L 79.316036 -274.499859 \n",
       "L 72.690433 -280.55675 \n",
       "L 66.06483 -285.859971 \n",
       "L 59.439227 -290.342424 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p0430146c4f)\">\n",
       "     <use xlink:href=\"#mf295aca3ec\" x=\"0\" y=\"322.510875\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m050b5281b8\" d=\"M 59.439227 -184.995561 \n",
       "L 59.439227 -184.99461 \n",
       "L 66.06483 -188.361254 \n",
       "L 72.690433 -192.571823 \n",
       "L 79.316036 -197.611976 \n",
       "L 85.941639 -203.39254 \n",
       "L 92.567243 -209.743389 \n",
       "L 99.192845 -216.416064 \n",
       "L 105.81845 -223.095727 \n",
       "L 112.44405 -229.419332 \n",
       "L 119.069655 -234.655146 \n",
       "L 125.695259 -231.160577 \n",
       "L 132.320859 -228.722116 \n",
       "L 138.946464 -227.93904 \n",
       "L 145.572063 -228.806124 \n",
       "L 152.197673 -231.166828 \n",
       "L 158.823273 -234.703448 \n",
       "L 165.448873 -234.337847 \n",
       "L 172.074482 -228.652144 \n",
       "L 178.700082 -222.241222 \n",
       "L 185.325682 -215.446373 \n",
       "L 191.951291 -208.540582 \n",
       "L 198.576891 -201.708514 \n",
       "L 205.202491 -195.02277 \n",
       "L 211.8281 -188.434314 \n",
       "L 218.4537 -181.781103 \n",
       "L 225.0793 -174.816058 \n",
       "L 231.7049 -167.253967 \n",
       "L 238.3305 -158.833297 \n",
       "L 244.956119 -149.38456 \n",
       "L 251.581718 -138.490591 \n",
       "L 258.207318 -116.010471 \n",
       "L 264.832918 -94.348425 \n",
       "L 271.458518 -75.383648 \n",
       "L 278.084118 -60.579098 \n",
       "L 284.709737 -51.252198 \n",
       "L 291.335337 -48.423375 \n",
       "L 297.960937 -52.668241 \n",
       "L 304.586536 -63.996068 \n",
       "L 311.212136 -81.77815 \n",
       "L 317.837736 -104.74818 \n",
       "L 324.463355 -131.078455 \n",
       "L 331.088955 -158.52842 \n",
       "L 337.714555 -184.396433 \n",
       "L 344.340155 -205.767479 \n",
       "L 350.965754 -222.825886 \n",
       "L 357.591354 -234.007886 \n",
       "L 364.216973 -237.582686 \n",
       "L 370.842573 -233.286598 \n",
       "L 377.468173 -222.594676 \n",
       "L 384.093773 -206.873876 \n",
       "L 384.093773 -207.004985 \n",
       "L 384.093773 -207.004985 \n",
       "L 377.468173 -222.648958 \n",
       "L 370.842573 -233.340313 \n",
       "L 364.216973 -237.683332 \n",
       "L 357.591354 -234.101047 \n",
       "L 350.965754 -222.878892 \n",
       "L 344.340155 -205.823694 \n",
       "L 337.714555 -184.527652 \n",
       "L 331.088955 -158.556907 \n",
       "L 324.463355 -131.090339 \n",
       "L 317.837736 -104.755066 \n",
       "L 311.212136 -81.782876 \n",
       "L 304.586536 -63.999707 \n",
       "L 297.960937 -52.671306 \n",
       "L 291.335337 -48.426153 \n",
       "L 284.709737 -51.254932 \n",
       "L 278.084118 -60.581982 \n",
       "L 271.458518 -75.387045 \n",
       "L 264.832918 -94.353031 \n",
       "L 258.207318 -116.019063 \n",
       "L 251.581718 -138.62167 \n",
       "L 244.956119 -149.392669 \n",
       "L 238.3305 -158.837397 \n",
       "L 231.7049 -167.256806 \n",
       "L 225.0793 -174.818323 \n",
       "L 218.4537 -181.783085 \n",
       "L 211.8281 -188.436179 \n",
       "L 205.202491 -195.024635 \n",
       "L 198.576891 -201.710507 \n",
       "L 191.951291 -208.542854 \n",
       "L 185.325682 -215.449186 \n",
       "L 178.700082 -222.245133 \n",
       "L 172.074482 -228.658822 \n",
       "L 165.448873 -234.358873 \n",
       "L 158.823273 -234.726334 \n",
       "L 152.197673 -231.175736 \n",
       "L 145.572063 -228.812631 \n",
       "L 138.946464 -227.945155 \n",
       "L 132.320859 -228.72926 \n",
       "L 125.695259 -231.172462 \n",
       "L 119.069655 -234.783361 \n",
       "L 112.44405 -229.428407 \n",
       "L 105.81845 -223.099968 \n",
       "L 99.192845 -216.418758 \n",
       "L 92.567243 -209.745354 \n",
       "L 85.941639 -203.394099 \n",
       "L 79.316036 -197.613278 \n",
       "L 72.690433 -192.572963 \n",
       "L 66.06483 -188.362281 \n",
       "L 59.439227 -184.995561 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p0430146c4f)\">\n",
       "     <use xlink:href=\"#m050b5281b8\" x=\"0\" y=\"322.510875\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m36dd1aedfd\" d=\"M 59.439227 -290.343375 \n",
       "L 59.439227 -290.342424 \n",
       "L 66.06483 -285.859971 \n",
       "L 72.690433 -280.55675 \n",
       "L 79.316036 -274.499859 \n",
       "L 85.941639 -267.833527 \n",
       "L 92.567243 -260.780446 \n",
       "L 99.192845 -253.63367 \n",
       "L 105.81845 -246.738928 \n",
       "L 112.44405 -240.469777 \n",
       "L 119.069655 -235.437313 \n",
       "L 125.695259 -239.598784 \n",
       "L 132.320859 -242.758482 \n",
       "L 138.946464 -244.335373 \n",
       "L 145.572063 -244.22008 \n",
       "L 152.197673 -242.424633 \n",
       "L 158.823273 -239.085616 \n",
       "L 165.448873 -239.107413 \n",
       "L 172.074482 -243.670101 \n",
       "L 178.700082 -247.882075 \n",
       "L 185.325682 -251.096208 \n",
       "L 191.951291 -252.679125 \n",
       "L 198.576891 -252.042232 \n",
       "L 205.202491 -248.678399 \n",
       "L 211.8281 -242.197626 \n",
       "L 218.4537 -232.361294 \n",
       "L 225.0793 -219.115116 \n",
       "L 231.7049 -202.619749 \n",
       "L 238.3305 -183.277118 \n",
       "L 244.956119 -161.748669 \n",
       "L 251.581718 -139.255646 \n",
       "L 258.207318 -127.689308 \n",
       "L 264.832918 -116.120357 \n",
       "L 271.458518 -104.996476 \n",
       "L 278.084118 -95.2837 \n",
       "L 284.709737 -88.079951 \n",
       "L 291.335337 -84.483014 \n",
       "L 297.960937 -85.433495 \n",
       "L 304.586536 -91.549591 \n",
       "L 311.212136 -102.980071 \n",
       "L 317.837736 -119.307763 \n",
       "L 324.463355 -139.515759 \n",
       "L 331.088955 -162.048639 \n",
       "L 337.714555 -185.160685 \n",
       "L 344.340155 -207.551387 \n",
       "L 350.965754 -224.717864 \n",
       "L 357.591354 -235.084367 \n",
       "L 364.216973 -238.579109 \n",
       "L 370.842573 -235.153623 \n",
       "L 377.468173 -224.442115 \n",
       "L 384.093773 -207.638773 \n",
       "L 384.093773 -207.769882 \n",
       "L 384.093773 -207.769882 \n",
       "L 377.468173 -224.496397 \n",
       "L 370.842573 -235.207337 \n",
       "L 364.216973 -238.679755 \n",
       "L 357.591354 -235.177528 \n",
       "L 350.965754 -224.77087 \n",
       "L 344.340155 -207.607602 \n",
       "L 337.714555 -185.291904 \n",
       "L 331.088955 -162.077126 \n",
       "L 324.463355 -139.527643 \n",
       "L 317.837736 -119.314649 \n",
       "L 311.212136 -102.984797 \n",
       "L 304.586536 -91.55323 \n",
       "L 297.960937 -85.436561 \n",
       "L 291.335337 -84.485793 \n",
       "L 284.709737 -88.082684 \n",
       "L 278.084118 -95.286585 \n",
       "L 271.458518 -104.999874 \n",
       "L 264.832918 -116.124963 \n",
       "L 258.207318 -127.6979 \n",
       "L 251.581718 -139.386725 \n",
       "L 244.956119 -161.756778 \n",
       "L 238.3305 -183.281221 \n",
       "L 231.7049 -202.622588 \n",
       "L 225.0793 -219.117382 \n",
       "L 218.4537 -232.363276 \n",
       "L 211.8281 -242.199491 \n",
       "L 205.202491 -248.680267 \n",
       "L 198.576891 -252.044224 \n",
       "L 191.951291 -252.681398 \n",
       "L 185.325682 -251.099021 \n",
       "L 178.700082 -247.885987 \n",
       "L 172.074482 -243.676778 \n",
       "L 165.448873 -239.12844 \n",
       "L 158.823273 -239.108501 \n",
       "L 152.197673 -242.433542 \n",
       "L 145.572063 -244.226586 \n",
       "L 138.946464 -244.34149 \n",
       "L 132.320859 -242.765626 \n",
       "L 125.695259 -239.610669 \n",
       "L 119.069655 -235.565528 \n",
       "L 112.44405 -240.478853 \n",
       "L 105.81845 -246.74317 \n",
       "L 99.192845 -253.636364 \n",
       "L 92.567243 -260.782411 \n",
       "L 85.941639 -267.835086 \n",
       "L 79.316036 -274.501162 \n",
       "L 72.690433 -280.55789 \n",
       "L 66.06483 -285.860998 \n",
       "L 59.439227 -290.343375 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p0430146c4f)\">\n",
       "     <use xlink:href=\"#m36dd1aedfd\" x=\"0\" y=\"322.510875\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <defs>\n",
       "     <path id=\"m2012ab24fa\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p0430146c4f)\">\n",
       "     <use xlink:href=\"#m2012ab24fa\" x=\"361.243318\" y=\"84.997379\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m2012ab24fa\" x=\"162.151989\" y=\"85.649888\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m2012ab24fa\" x=\"119.149308\" y=\"87.398073\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m2012ab24fa\" x=\"251.581718\" y=\"183.572413\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m2012ab24fa\" x=\"384.093773\" y=\"115.212685\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m2012ab24fa\" x=\"337.714555\" y=\"137.691932\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <path d=\"M 59.439227 84.841882 \n",
       "L 66.06483 85.399748 \n",
       "L 72.690433 85.946019 \n",
       "L 79.316036 86.454307 \n",
       "L 85.941639 86.897063 \n",
       "L 92.567243 87.247975 \n",
       "L 99.192845 87.484662 \n",
       "L 105.81845 87.591427 \n",
       "L 112.44405 87.561783 \n",
       "L 119.069655 87.400538 \n",
       "L 125.695259 87.125252 \n",
       "L 132.320859 86.767004 \n",
       "L 138.946464 86.370611 \n",
       "L 145.572063 85.99452 \n",
       "L 152.197673 85.71069 \n",
       "L 158.823273 85.6049 \n",
       "L 165.448873 85.777732 \n",
       "L 172.074482 86.346414 \n",
       "L 178.700082 87.447271 \n",
       "L 185.325682 89.238178 \n",
       "L 191.951291 91.899884 \n",
       "L 198.576891 95.634505 \n",
       "L 205.202491 100.659357 \n",
       "L 211.8281 107.193973 \n",
       "L 218.4537 115.438685 \n",
       "L 225.0793 125.544155 \n",
       "L 231.7049 137.572597 \n",
       "L 238.3305 151.453616 \n",
       "L 244.956119 166.940206 \n",
       "L 251.581718 183.572217 \n",
       "L 258.207318 200.656689 \n",
       "L 264.832918 217.274181 \n",
       "L 271.458518 232.319114 \n",
       "L 278.084118 244.578034 \n",
       "L 284.709737 252.843434 \n",
       "L 291.335337 256.056291 \n",
       "L 297.960937 253.458474 \n",
       "L 304.586536 244.736226 \n",
       "L 311.212136 230.129401 \n",
       "L 317.837736 210.479457 \n",
       "L 324.463355 187.207826 \n",
       "L 331.088955 162.208102 \n",
       "L 337.714555 137.666707 \n",
       "L 344.340155 115.823335 \n",
       "L 350.965754 98.712497 \n",
       "L 357.591354 87.918168 \n",
       "L 364.216973 84.379655 \n",
       "L 370.842573 88.263907 \n",
       "L 377.468173 98.965339 \n",
       "L 384.093773 115.188996 \n",
       "\" clip-path=\"url(#p0430146c4f)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_17\">\n",
       "    <path d=\"M 59.439227 144.095661 \n",
       "L 66.06483 136.303614 \n",
       "L 72.690433 128.629509 \n",
       "L 79.316036 121.189891 \n",
       "L 85.941639 114.098383 \n",
       "L 92.567243 107.464101 \n",
       "L 99.192845 101.390067 \n",
       "L 105.81845 95.971811 \n",
       "L 112.44405 91.29599 \n",
       "L 119.069655 87.439179 \n",
       "L 125.695259 84.466792 \n",
       "L 132.320859 82.432156 \n",
       "L 138.946464 81.375696 \n",
       "L 145.572063 81.32434 \n",
       "L 152.197673 82.291005 \n",
       "L 158.823273 84.274273 \n",
       "L 165.448873 87.258189 \n",
       "L 172.074482 91.212171 \n",
       "L 178.700082 96.09104 \n",
       "L 185.325682 101.835069 \n",
       "L 191.951291 108.370183 \n",
       "L 198.576891 115.608025 \n",
       "L 205.202491 123.446219 \n",
       "L 211.8281 131.768397 \n",
       "L 218.4537 140.444162 \n",
       "L 225.0793 149.329197 \n",
       "L 231.7049 158.264996 \n",
       "L 238.3305 167.078503 \n",
       "L 244.956119 175.581992 \n",
       "L 251.581718 183.572413 \n",
       "L 258.207318 190.831544 \n",
       "L 264.832918 197.125953 \n",
       "L 271.458518 202.208092 \n",
       "L 278.084118 205.818438 \n",
       "L 284.709737 207.689955 \n",
       "L 291.335337 207.555576 \n",
       "L 297.960937 205.160581 \n",
       "L 304.586536 200.281693 \n",
       "L 311.212136 192.755368 \n",
       "L 317.837736 182.51832 \n",
       "L 324.463355 169.662828 \n",
       "L 331.088955 154.50893 \n",
       "L 337.714555 137.691932 \n",
       "L 344.340155 120.258413 \n",
       "L 350.965754 103.751577 \n",
       "L 357.591354 90.248013 \n",
       "L 364.216973 82.28031 \n",
       "L 370.842573 82.546595 \n",
       "L 377.468173 93.284679 \n",
       "L 384.093773 115.212685 \n",
       "\" clip-path=\"url(#p0430146c4f)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_18\">\n",
       "    <defs>\n",
       "     <path id=\"m4c70469665\" d=\"M 0 2.4 \n",
       "C 0.636487 2.4 1.246992 2.147121 1.697056 1.697056 \n",
       "C 2.147121 1.246992 2.4 0.636487 2.4 0 \n",
       "C 2.4 -0.636487 2.147121 -1.246992 1.697056 -1.697056 \n",
       "C 1.246992 -2.147121 0.636487 -2.4 0 -2.4 \n",
       "C -0.636487 -2.4 -1.246992 -2.147121 -1.697056 -1.697056 \n",
       "C -2.147121 -1.246992 -2.4 -0.636487 -2.4 0 \n",
       "C -2.4 0.636487 -2.147121 1.246992 -1.697056 1.697056 \n",
       "C -1.246992 2.147121 -0.636487 2.4 0 2.4 \n",
       "z\n",
       "\" style=\"stroke: #008000\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p0430146c4f)\">\n",
       "     <use xlink:href=\"#m4c70469665\" x=\"337.714552\" y=\"137.691923\" style=\"fill: #008000; stroke: #008000\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 43.2065 271.229261 \n",
       "L 43.2065 49.554022 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 59.439227 286.1835 \n",
       "L 384.093773 286.1835 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_17\">\n",
       "    <!-- BGO iteration #3 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(186.017 14.0715) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-42\" d=\"M 469 0 \n",
       "L 469 4581 \n",
       "L 2188 4581 \n",
       "Q 2713 4581 3030 4442 \n",
       "Q 3347 4303 3526 4014 \n",
       "Q 3706 3725 3706 3409 \n",
       "Q 3706 3116 3547 2856 \n",
       "Q 3388 2597 3066 2438 \n",
       "Q 3481 2316 3704 2022 \n",
       "Q 3928 1728 3928 1328 \n",
       "Q 3928 1006 3792 729 \n",
       "Q 3656 453 3456 303 \n",
       "Q 3256 153 2954 76 \n",
       "Q 2653 0 2216 0 \n",
       "L 469 0 \n",
       "z\n",
       "M 1075 2656 \n",
       "L 2066 2656 \n",
       "Q 2469 2656 2644 2709 \n",
       "Q 2875 2778 2992 2937 \n",
       "Q 3109 3097 3109 3338 \n",
       "Q 3109 3566 3000 3739 \n",
       "Q 2891 3913 2687 3977 \n",
       "Q 2484 4041 1991 4041 \n",
       "L 1075 4041 \n",
       "L 1075 2656 \n",
       "z\n",
       "M 1075 541 \n",
       "L 2216 541 \n",
       "Q 2509 541 2628 563 \n",
       "Q 2838 600 2978 687 \n",
       "Q 3119 775 3209 942 \n",
       "Q 3300 1109 3300 1328 \n",
       "Q 3300 1584 3169 1773 \n",
       "Q 3038 1963 2805 2039 \n",
       "Q 2572 2116 2134 2116 \n",
       "L 1075 2116 \n",
       "L 1075 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-47\" d=\"M 2638 1797 \n",
       "L 2638 2334 \n",
       "L 4578 2338 \n",
       "L 4578 638 \n",
       "Q 4131 281 3656 101 \n",
       "Q 3181 -78 2681 -78 \n",
       "Q 2006 -78 1454 211 \n",
       "Q 903 500 622 1047 \n",
       "Q 341 1594 341 2269 \n",
       "Q 341 2938 620 3517 \n",
       "Q 900 4097 1425 4378 \n",
       "Q 1950 4659 2634 4659 \n",
       "Q 3131 4659 3532 4498 \n",
       "Q 3934 4338 4162 4050 \n",
       "Q 4391 3763 4509 3300 \n",
       "L 3963 3150 \n",
       "Q 3859 3500 3706 3700 \n",
       "Q 3553 3900 3268 4020 \n",
       "Q 2984 4141 2638 4141 \n",
       "Q 2222 4141 1919 4014 \n",
       "Q 1616 3888 1430 3681 \n",
       "Q 1244 3475 1141 3228 \n",
       "Q 966 2803 966 2306 \n",
       "Q 966 1694 1177 1281 \n",
       "Q 1388 869 1791 669 \n",
       "Q 2194 469 2647 469 \n",
       "Q 3041 469 3416 620 \n",
       "Q 3791 772 3984 944 \n",
       "L 3984 1797 \n",
       "L 2638 1797 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-23\" d=\"M 322 -78 \n",
       "L 594 1253 \n",
       "L 66 1253 \n",
       "L 66 1719 \n",
       "L 688 1719 \n",
       "L 919 2853 \n",
       "L 66 2853 \n",
       "L 66 3319 \n",
       "L 1013 3319 \n",
       "L 1284 4659 \n",
       "L 1753 4659 \n",
       "L 1481 3319 \n",
       "L 2466 3319 \n",
       "L 2738 4659 \n",
       "L 3209 4659 \n",
       "L 2938 3319 \n",
       "L 3478 3319 \n",
       "L 3478 2853 \n",
       "L 2844 2853 \n",
       "L 2609 1719 \n",
       "L 3478 1719 \n",
       "L 3478 1253 \n",
       "L 2516 1253 \n",
       "L 2244 -78 \n",
       "L 1775 -78 \n",
       "L 2044 1253 \n",
       "L 1063 1253 \n",
       "L 791 -78 \n",
       "L 322 -78 \n",
       "z\n",
       "M 1156 1719 \n",
       "L 2138 1719 \n",
       "L 2372 2853 \n",
       "L 1388 2853 \n",
       "L 1156 1719 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-42\"/>\n",
       "     <use xlink:href=\"#ArialMT-47\" x=\"66.699219\"/>\n",
       "     <use xlink:href=\"#ArialMT-4f\" x=\"144.482422\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"222.265625\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"250.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"272.265625\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"300.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"355.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"388.964844\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"444.580078\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"472.363281\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"494.580078\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"550.195312\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"605.810547\"/>\n",
       "     <use xlink:href=\"#ArialMT-23\" x=\"633.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-33\" x=\"689.208984\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_19\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m2012ab24fa\" x=\"59.9265\" y=\"207.53075\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 210.61075) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_20\">\n",
       "     <path d=\"M 51.1265 220.11475 \n",
       "L 59.9265 220.11475 \n",
       "L 68.7265 220.11475 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 223.19475) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 51.1265 237.35175 \n",
       "L 68.7265 237.35175 \n",
       "L 68.7265 231.19175 \n",
       "L 51.1265 231.19175 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 237.35175) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 51.1265 251.51975 \n",
       "L 68.7265 251.51975 \n",
       "L 68.7265 245.35975 \n",
       "L 51.1265 245.35975 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 251.51975) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_21\">\n",
       "     <path d=\"M 51.1265 260.986625 \n",
       "L 59.9265 260.986625 \n",
       "L 68.7265 260.986625 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_22\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 264.066625) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_22\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m4c70469665\" x=\"59.9265\" y=\"273.4345\" style=\"fill: #008000; stroke: #008000\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_23\">\n",
       "     <!-- Next observation -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 276.5145) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4e\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"72.216797\"/>\n",
       "      <use xlink:href=\"#ArialMT-78\" x=\"127.832031\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"177.832031\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"205.615234\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"233.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"289.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"344.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"394.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"450.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"533.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"589.160156\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"616.943359\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"639.160156\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"694.775391\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p0430146c4f\">\n",
       "   <rect x=\"43.2065\" y=\"20.0715\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "X_design = torch.from_numpy(x).float()\n",
    "model.train()\n",
    "maximize_naive(f, model, X_design, max_it=3)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Observe that the algorithm misses the actual maximum.\n",
    "It gets trapped.\n",
    "This is because using the posterior mean as an acquisition function focuses too much on **exploiting** the currently available information but fails to **explore** regions of the input space that we have yet to visit.\n",
    "\n",
    "### Questions\n",
    "\n",
    "+ Experiment with different numbers of initial observations. How many must you use for the algorithm to converge to the global maximum?"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "celltoolbar": "Tags",
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.11.6"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
